@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -25,8 +25,8 @@ const float AudioLevel::DB_FLOOR = -1000.0;
 
 struct FaderDescription
 {
-    FaderDescription(float _minDb, float _maxDb, float _zeroPoint) :
-	minDb(_minDb), maxDb(_maxDb), zeroPoint(_zeroPoint) { }
+    FaderDescription(float i_minDb, float i_maxDb, float i_zeroPoint) :
+        minDb(i_minDb), maxDb(i_maxDb), zeroPoint(i_zeroPoint) { }
 
     float minDb;
     float maxDb;
@@ -91,17 +91,17 @@ static float iec_fader_to_dB(float def)  // Meter deflection %age
     float db = 0.0f;
 
     if (def >= 50.0f) {
-	db = (def - 50.0f) / 2.5f - 20.0f;
+        db = (def - 50.0f) / 2.5f - 20.0f;
     } else if (def >= 30.0f) {
-	db = (def - 30.0f) / 2.0f - 30.0f;
+        db = (def - 30.0f) / 2.0f - 30.0f;
     } else if (def >= 15.0f) {
-	db = (def - 15.0f) / 1.5f - 40.0f;
+        db = (def - 15.0f) / 1.5f - 40.0f;
     } else if (def >= 7.5f) {
-	db = (def - 7.5f) / 0.75f - 50.0f;
+        db = (def - 7.5f) / 0.75f - 50.0f;
     } else if (def >= 2.5f) {
-	db = (def - 2.5f) / 0.5f - 60.0f;
+        db = (def - 2.5f) / 0.5f - 60.0f;
     } else {
-	db = (def / 0.25f) - 70.0f;
+        db = (def / 0.25f) - 70.0f;
     }
 
     return db;
@@ -114,32 +114,32 @@ AudioLevel::fader_to_dB(int level, int maxLevel, FaderType type)
 
     if (type == IEC268Meter || type == IEC268LongMeter) {
 
-	float maxPercent = iec_dB_to_fader(faderTypes[type].maxDb);
-	float percent = float(level) * maxPercent / float(maxLevel);
-	float dB = iec_fader_to_dB(percent);
-	return dB;
+        float maxPercent = iec_dB_to_fader(faderTypes[type].maxDb);
+        float percent = float(level) * maxPercent / float(maxLevel);
+        float dB = iec_fader_to_dB(percent);
+        return dB;
 
     } else { // scale proportional to sqrt(fabs(dB))
 
-	int zeroLevel = int(maxLevel * faderTypes[type].zeroPoint);
-    
-	if (level >= zeroLevel) {
-	    
-	    float value = level - zeroLevel;
-	    float scale = float(maxLevel - zeroLevel) /
-		sqrtf(faderTypes[type].maxDb);
-	    value /= scale;
-	    float dB = powf(value, 2.0);
-	    return dB;
-	    
-	} else {
-	    
-	    float value = zeroLevel - level;
-	    float scale = zeroLevel / sqrtf(0.0 - faderTypes[type].minDb);
-	    value /= scale;
-	    float dB = powf(value, 2.0);
-	    return 0.0 - dB;
-	}
+        int zeroLevel = int(maxLevel * faderTypes[type].zeroPoint);
+
+        if (level >= zeroLevel) {
+
+            float value = level - zeroLevel;
+            float scale = float(maxLevel - zeroLevel) /
+                sqrtf(faderTypes[type].maxDb);
+            value /= scale;
+            float dB = powf(value, 2.0);
+            return dB;
+
+        } else {
+
+            float value = zeroLevel - level;
+            float scale = zeroLevel / sqrtf(0.0 - faderTypes[type].minDb);
+            value /= scale;
+            float dB = powf(value, 2.0);
+            return 0.0 - dB;
+        }
     }
 }
 
@@ -151,46 +151,46 @@ AudioLevel::dB_to_fader(float dB, int maxLevel, FaderType type)
 
     if (type == IEC268Meter || type == IEC268LongMeter) {
 
-	// The IEC scale gives a "percentage travel" for a given dB
-	// level, but it reaches 100% at 0dB.  So we want to treat the
-	// result not as a percentage, but as a scale between 0 and
-	// whatever the "percentage" for our (possibly >0dB) max dB is.
-	
-	float maxPercent = iec_dB_to_fader(faderTypes[type].maxDb);
-	float percent = iec_dB_to_fader(dB);
-	int faderLevel = int((maxLevel * percent) / maxPercent + 0.01);
-	
-	if (faderLevel < 0) faderLevel = 0;
-	if (faderLevel > maxLevel) faderLevel = maxLevel;
-	return faderLevel;
+        // The IEC scale gives a "percentage travel" for a given dB
+        // level, but it reaches 100% at 0dB.  So we want to treat the
+        // result not as a percentage, but as a scale between 0 and
+        // whatever the "percentage" for our (possibly >0dB) max dB is.
+
+        float maxPercent = iec_dB_to_fader(faderTypes[type].maxDb);
+        float percent = iec_dB_to_fader(dB);
+        int faderLevel = int((maxLevel * percent) / maxPercent + 0.01);
+
+        if (faderLevel < 0) faderLevel = 0;
+        if (faderLevel > maxLevel) faderLevel = maxLevel;
+        return faderLevel;
 
     } else {
 
-	int zeroLevel = int(maxLevel * faderTypes[type].zeroPoint);
+        int zeroLevel = int(maxLevel * faderTypes[type].zeroPoint);
 
-	if (dB >= 0.0) {
-	    
-	    float value = sqrtf(dB);
-	    float scale = (maxLevel - zeroLevel) / sqrtf(faderTypes[type].maxDb);
-	    value *= scale;
-	    int level = int(value + 0.01) + zeroLevel;
-	    if (level > maxLevel) level = maxLevel;
-	    return level;
-	    
-	} else {
+        if (dB >= 0.0) {
 
-	    dB = 0.0 - dB;
-	    float value = sqrtf(dB);
-	    float scale = zeroLevel / sqrtf(0.0 - faderTypes[type].minDb);
-	    value *= scale;
-	    int level = zeroLevel - int(value + 0.01);
-	    if (level < 0) level = 0;
-	    return level;
-	}
+            float value = sqrtf(dB);
+            float scale = (maxLevel - zeroLevel) / sqrtf(faderTypes[type].maxDb);
+            value *= scale;
+            int level = int(value + 0.01) + zeroLevel;
+            if (level > maxLevel) level = maxLevel;
+            return level;
+
+        } else {
+
+            dB = 0.0 - dB;
+            float value = sqrtf(dB);
+            float scale = zeroLevel / sqrtf(0.0 - faderTypes[type].minDb);
+            value *= scale;
+            int level = zeroLevel - int(value + 0.01);
+            if (level < 0) level = 0;
+            return level;
+        }
     }
 }
 
-	
+
 float
 AudioLevel::fader_to_multiplier(int level, int maxLevel, FaderType type)
 {
@@ -213,12 +213,12 @@ getPreviewLevelCache(int levels)
 {
     LevelList &ll = previewLevelCache[levels];
     if (ll.empty()) {
-	for (int i = 0; i <= levels; ++i) {
-	    float m = AudioLevel::fader_to_multiplier
-		(i, levels, AudioLevel::PreviewLevel);
-	    if (levels == 1) m /= 100; // noise
-	    ll.push_back(m);
-	}
+        for (int i = 0; i <= levels; ++i) {
+            float m = AudioLevel::fader_to_multiplier
+                (i, levels, AudioLevel::PreviewLevel);
+            if (levels == 1) m /= 100; // noise
+            ll.push_back(m);
+        }
     }
     return ll;
 }
@@ -234,23 +234,23 @@ AudioLevel::multiplier_to_preview(float m, int levels)
     // binary search
     int level = -1;
     while (result < 0) {
-	int newlevel = (lo + hi) / 2;
-	if (newlevel == level ||
-	    newlevel == 0 ||
-	    newlevel == levels) {
-	    result = newlevel;
-	    break;
-	}
-	level = newlevel;
-	if (ll[level] >= m) {
-	    hi = level;
-	} else if (ll[level+1] >= m) {
-	    result = level;
-	} else {
-	    lo = level;
-	}
+        int newlevel = (lo + hi) / 2;
+        if (newlevel == level ||
+            newlevel == 0 ||
+            newlevel == levels) {
+            result = newlevel;
+            break;
+        }
+        level = newlevel;
+        if (ll[level] >= m) {
+            hi = level;
+        } else if (ll[level+1] >= m) {
+            result = level;
+        } else {
+            lo = level;
+        }
     }
-	
+
     return result;
 }
 
