@@ -1,7 +1,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -11,8 +11,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _BASE_PROPERTIES_H_
-#define _BASE_PROPERTIES_H_
+#ifndef RG_BASE_PROPERTIES_H
+#define RG_BASE_PROPERTIES_H
 
 #include "base/PropertyName.h"
 
