@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -13,13 +13,9 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _COMPOSITION_H_
-#define _COMPOSITION_H_
+#ifndef RG_COMPOSITION_H
+#define RG_COMPOSITION_H
 
-#include <set>
-#include <map>
-
-#include <QtCore/QWeakPointer>
 
 #include "FastVector.h"
 
@@ -33,6 +29,13 @@
 
 #include "Marker.h"
 
+// Qt
+#include <QtCore/QWeakPointer>
+
+// System
+#include <set>
+#include <map>
+
 namespace Rosegarden 
 {
 // We store tempo in quarter-notes per minute * 10^5 (hundred
@@ -109,9 +112,11 @@ public:
 
     timeT getStartMarker() const { return m_startMarker; }
     timeT getEndMarker() const { return m_endMarker; }
+    bool autoExpandEnabled() { return m_autoExpand; }
 
     void setStartMarker(const timeT &sM);
     void setEndMarker(const timeT &eM);
+    void setAutoExpand(bool autoExpand) { m_autoExpand = autoExpand; }
 
 
     //////
@@ -1072,6 +1077,7 @@ protected:
     //
     timeT                             m_startMarker;
     timeT                             m_endMarker;
+    bool                              m_autoExpand;
 
     static int                        m_defaultNbBars;
 
