@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -25,7 +25,9 @@
 #include "base/Segment.h"
 #include "gui/rulers/ControllerEventAdapter.h"
 #include "misc/Debug.h"
-#include <assert.h>
+
+#include <QtGlobal>
+
 #include <limits>
 
 // #define DEBUG_CONTROLLER_CONTEXT 1
@@ -137,8 +139,10 @@ getControllerValue(Instrument *instrument, Segment *a, Segment *b,
     Profiler profiler("ControllerContextMap::getControllerValue", false);
 
     // Should only get these two types.
-    assert((eventType == Controller::EventType) ||
-           (eventType == PitchBend::EventType));
+    Q_ASSERT_X((eventType == Controller::EventType) ||
+               (eventType == PitchBend::EventType),
+               "getControllerValue",
+               "got an unexpected event type");
     
     // We have cached the latest value of all controllers we've
     // inserted.  Find the relevant cache.
@@ -221,7 +225,7 @@ getControlParameter(Instrument *instrument,
 {
     Device * device = instrument->getDevice();
     const Controllable *c = device->getControllable();
-    assert(c);
+    Q_CHECK_PTR(c);
     return c->getControlParameter(eventType, controllerId);
 }
 
@@ -269,10 +273,10 @@ makeControlValueAbsolute(Instrument *instrument, Segment *a,
     ControllerEventAdapter adapter(e);
     long oldValue;
     adapter.getValue(oldValue);
-    const ControlParameter * m_controlParameter =
+    const ControlParameter * controlParameter =
         getControlParameter(instrument, eventType, controllerId);
     long newValue =
-        makeAbsolute(m_controlParameter, oldValue + baseline);
+        makeAbsolute(controlParameter, oldValue + baseline);
     adapter.setValue(newValue);
 #ifdef DEBUG_CONTROLLER_CONTEXT
     SEQMAN_DEBUG << "ControllerContextMap::makeControlValueAbsolute"
@@ -308,7 +312,9 @@ storeLatestValue(Event *e)
         m_latestValues[controllerId] = toCache;
     } else {
         // We are only expecting these two types.
-        assert(eventType == PitchBend::EventType);
+        Q_ASSERT_X(eventType == PitchBend::EventType,
+                   "storeLatestValue",
+                   "got an unexpected event type");
         // Set it.
         m_PitchBendLatestValue = Maybe(true, toCache);
     } 
