@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _CONTROLLERCONTEXT_H_
-#define _CONTROLLERCONTEXT_H_
+#ifndef RG_CONTROLLERCONTEXT_H
+#define RG_CONTROLLERCONTEXT_H
 
 #include <base/Event.h>
 #include <map>
@@ -159,4 +159,4 @@ private:
 };
 }
 
-#endif /* ifndef _CONTROLLERCONTEXT_H_ */
+#endif /* ifndef RG_CONTROLLERCONTEXT_H */
