@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -21,6 +21,9 @@
 #include "base/Profiler.h"
 #include "base/SegmentLinker.h"
 #include "document/DocumentGet.h"
+#include "gui/general/GUIPalette.h"
+
+#include <QtGlobal>
 
 #include <iostream>
 #include <algorithm>
@@ -39,7 +42,7 @@ using std::string;
 
 //#define DEBUG_NORMALIZE_RESTS 1
 
-static int _runtimeSegmentId = 0;
+static int g_runtimeSegmentId = 0;
 
 Segment::Segment(SegmentType segmentType, timeT startTime) :
     EventContainer(),
@@ -68,7 +71,7 @@ Segment::Segment(SegmentType segmentType, timeT startTime) :
     m_notifyResizeLocked(false),
     m_memoStart(0),
     m_memoEndMarkerTime(0),
-    m_runtimeSegmentId(_runtimeSegmentId++),
+    m_runtimeSegmentId(g_runtimeSegmentId++),
     m_snapGridSize(-1),
     m_viewFeatures(0),
     m_autoFade(false),
@@ -113,7 +116,7 @@ Segment::Segment(const Segment &segment):
     m_notifyResizeLocked(false),  // To copy a segment while notifications
     m_memoStart(0),               // are locked doesn't sound as a good
     m_memoEndMarkerTime(0),       // idea.
-    m_runtimeSegmentId(_runtimeSegmentId++),
+    m_runtimeSegmentId(g_runtimeSegmentId++),
     m_snapGridSize(-1),
     m_viewFeatures(0),
     m_autoFade(segment.isAutoFading()),
@@ -494,6 +497,7 @@ Segment::setEndTime(timeT t)
             }
         } else if (t > endTime) {
             fillWithRests(endTime, t);
+            normalizeRests(endTime, t);
         }
     }
 }
@@ -550,7 +554,7 @@ Segment::updateRefreshStatuses(timeT startTime, timeT endTime)
 Segment::iterator
 Segment::insert(Event *e)
 {
-    assert(e);
+    Q_CHECK_PTR(e);
 
     // Event Start Time
     timeT t0 = e->getAbsoluteTime();
@@ -602,7 +606,7 @@ Segment::erase(iterator pos)
 {
     Event *e = *pos;
 
-    assert(e);
+    Q_CHECK_PTR(e);
     
 
     timeT t0 = e->getAbsoluteTime();
@@ -645,7 +649,7 @@ Segment::erase(iterator from, iterator to)
         ++j;
 
         Event *e = *i;
-        assert(e);
+        Q_CHECK_PTR(e);
 
         EventContainer::erase(i);
         notifyRemove(e);
@@ -839,6 +843,7 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
 
     timeT segmentEndTime = m_endTime;
 
+    // Begin iterator.
     iterator ia = findNearestTime(startTime);
     if (ia == end()) ia = begin();
     if (ia == end()) { // the segment is empty
@@ -859,6 +864,7 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
         }
     }
 
+    // End iterator.
     iterator ib = findTime(endTime);
     while (ib != end()) {
         if ((*ib)->isa(Note::EventType) ||
@@ -904,6 +910,7 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
         }
     }
 
+    // For each event within the adjusted range, erase each rest.
     for (iterator i = ia, j = i; i != ib && i != end(); i = j) {
         ++j;
         if ((*i)->isa(Note::EventRestType) &&
@@ -931,8 +938,6 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
     // the one ending sooner.  Each time an event ends, we start
     // a candidate gap.
 
-    std::vector<std::pair<timeT, timeT> > gaps;
-
     timeT lastNoteStarts = startTime;
     timeT lastNoteEnds = startTime;
 
@@ -953,9 +958,10 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
         lastNoteEnds = lastNoteStarts;
     }
 
-    iterator i = ia;
+    std::vector<std::pair<timeT, timeT> > gaps;
 
-    for (; i != ib && i != end(); ++i) {
+    // For each event, add any gaps to the gaps vector.
+    for (iterator i = ia; i != ib && i != end(); ++i) {
 
         // Boundary events for sets of rests may be notes (obviously),
         // text events (because they need to be "attached" to
@@ -1015,6 +1021,7 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
 
     timeT duration;
 
+    // For each gap, fill it in with rests.
     for (size_t gi = 0; gi < gaps.size(); ++gi) {
 
 #ifdef DEBUG_NORMALIZE_RESTS
@@ -1407,16 +1414,29 @@ Segment::getRepeatEndTime() const
     timeT endMarker = getEndMarkerTime();
 
     if (m_repeating && m_composition) {
-        Composition::iterator i(m_composition->findSegment(this));
-        assert(i != m_composition->end());
-        ++i;
-        if (i != m_composition->end() && (*i)->getTrack() == getTrack()) {
-            timeT t = (*i)->getStartTime();
-            if (t < endMarker) return endMarker;
-            else return t;
-        } else {
-            return m_composition->getEndMarker();
+        timeT endTime = m_composition->getEndMarker();
+        
+        for (Composition::iterator i(m_composition->begin());
+             i != m_composition->end(); ++i) {
+          
+            if ((*i)->getTrack() != getTrack()) continue;
+            
+            timeT t1 = (*i)->getStartTime();
+            timeT t2 = (*i)->getEndMarkerTime();
+
+            if (t2 > endMarker) {
+                if (t1 < endTime) {
+                    if (t1 < endMarker) {
+                        endTime = endMarker;
+                        break;
+                    } else {
+                        endTime = t1;
+                    }
+                }
+            }
         }
+
+        return endTime;
     }
 
     return endMarker;
@@ -1567,6 +1587,35 @@ Segment::setColourIndex(const unsigned int input)
     notifyAppearanceChange();
 }
 
+QColor
+Segment::getPreviewColour() const
+{
+    // Select a preview colour for best visibility against the segment's
+    // colour.
+
+    // StaffHeader::updateHeader() does something similar.  Might want
+    // to offer a Colour::getVisibleForeground() to handle this concept
+    // in a more central location.  Like the unused
+    // Colour::getContrastingColour().
+
+    if (!m_composition) {
+        return Qt::black;
+    }
+
+    QColor segmentColour = GUIPalette::convertColour(
+            m_composition->getSegmentColourMap().getColourByIndex(m_colourIndex));
+
+    int intensity = qGray(segmentColour.rgb());
+
+    // Go with black for bright backgrounds
+    if (intensity > 127) {
+        return Qt::black;
+    }
+
+    // And white for dark backgrounds
+    return Qt::white;
+}
+
 void
 Segment::addEventRuler(const std::string &type, int controllerValue, bool active)
 {
