@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -28,6 +28,8 @@
 #include "RealTime.h"
 #include "MidiProgram.h"
 
+#include <QColor>
+
 namespace Rosegarden
 {
 
@@ -201,6 +203,8 @@ public:
     // Colour information
     void setColourIndex(const unsigned int input);
     unsigned int getColourIndex() const { return m_colourIndex; }
+    /// Get a high-contrast color to use for segment previews
+    QColor getPreviewColour() const;
 
     /**
      * Returns a numeric id of some sort
@@ -596,13 +600,14 @@ public:
     bool isRepeating() const { return m_repeating; }
     void setRepeating(bool value);
 
+
     /**
      * If this Segment is repeating, calculate and return the time at
-     * which the repeating stops.  This is the start time of the
-     * following Segment on the same Track, if any, or else the end
-     * time of the Composition.  If this Segment does not repeat, or
-     * the time calculated would precede the end time of the Segment,
-     * instead return the end time of the Segment.
+     * which the repeating stops.
+     * This is the time of the first part of another Segment on the same
+     * Track, if any, which follows the end of this Segment.
+     * If there is not such a Segment, instead return the end time of the
+     * Segment.
      */
     timeT getRepeatEndTime() const;
 
