@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -14,8 +14,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _SEGMENT_NOTATION_HELPER_H_
-#define _SEGMENT_NOTATION_HELPER_H_
+#ifndef RG_SEGMENT_NOTATION_HELPER_H
+#define RG_SEGMENT_NOTATION_HELPER_H
 
 #include "base/Segment.h"
 
