@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -165,12 +165,13 @@ EventSelection::addRemoveEvent(Event *e, EventFuncPtr insertEraseFn,
 {
     const Segment::const_iterator baseSegmentItr = m_originalSegment.find(e);
     
-    // Sanity Check
-    if (baseSegmentItr == m_originalSegment.end()) {
-        RG_DEBUG << "EventSelection::addRemoveEvent Sent event that can not be found "
-                  << "in segment.  Exiting method";
-    
-    }
+    //if (baseSegmentItr == m_originalSegment.end()) {
+    //    RG_DEBUG << "EventSelection::addRemoveEvent(): "
+    //             << "Sent event that can not be found in original segment.";
+        // Note: This is perfectly ok.  The rest of the code checks
+        //       baseSegmentIter to make sure it is valid before using
+        //       it.
+    //}
 
     timeT eventDuration = e->getDuration();
     if (eventDuration == 0) eventDuration = 1;
@@ -451,6 +452,18 @@ EventSelection::segmentDeleted(const Segment *)
               */
 }
 
+void
+EventSelection::dump() const
+{
+    RG_DEBUG << "EventSelection::dump()";
+    RG_DEBUG << "  m_beginTime: " << m_beginTime;
+    RG_DEBUG << "  m_endTime: " << m_endTime;
+    RG_DEBUG << "  m_haveRealStartTime: " << m_haveRealStartTime;
+}
+
+
+/** SegmentSelection **/
+
 bool SegmentSelection::hasNonAudioSegment() const
 {
     for (const_iterator i = begin(); i != end(); ++i) {
@@ -460,6 +473,7 @@ bool SegmentSelection::hasNonAudioSegment() const
     return false;
 }
 
+
 /** Templates that define methods of TimewiseSelection **/
 
 template <typename ElementInfo>
@@ -541,6 +555,7 @@ TimeSignatureSelection::AddToComposition(Composition *composition)
     }    
 }
 
+
 /** Methods of TempoSelection **/
 
 TempoSelection::TempoSelection() { }
@@ -612,6 +627,7 @@ TempoSelection::AddToComposition(Composition *composition)
     }
 }
 
+
 /** Methods of template helper MarkerElementInfo **/
 
 void
@@ -634,6 +650,7 @@ AddToComposition(Composition *composition,
 // see the method definitions.
 template class TimewiseSelection<MarkerElementInfo>;
 
+
 /** Methods of MarkerSelection **/
 
 MarkerSelection::MarkerSelection(Composition &composition, timeT beginTime,
