@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -18,8 +18,8 @@
 //
 
 
-#ifndef _TRACK_H_
-#define _TRACK_H_
+#ifndef RG_TRACK_H
+#define RG_TRACK_H
 
 #include <string>
 
@@ -164,5 +164,5 @@ private:
 
 }
 
-#endif // _TRACK_H_
+#endif // RG_TRACK_H
  
