@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -15,7 +15,8 @@
 
 #include "ViewElement.h"
 #include <iostream>
-#include <cassert>
+
+#include <QtGlobal>
 
 namespace Rosegarden 
 {
