@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -77,7 +77,7 @@ ParameterPattern::FlatPattern = &FlatParameterPattern::single;
     ParameterPattern::NAME(SOURCE, ENDOFARRAY(SOURCE))
 
 // Internal
-ParameterPattern * _VelocityPatterns[] = {
+ParameterPattern * velocityPatternsArray[] = {
     &FlatParameterPattern::single,
     &AlternatingParameterPattern::single,
     &LinearParameterPattern::crescendo,
@@ -93,13 +93,13 @@ ParameterPattern * _VelocityPatterns[] = {
 };
 
 // Internal
-ParameterPattern ** _EndVelocityPatterns = ENDOFARRAY(_VelocityPatterns);
+ParameterPattern ** endVelocityPatterns = ENDOFARRAY(velocityPatternsArray);
 
 // A vector of all the patterns that are useful for setting velocity.
 ParameterPattern::ParameterPatternVec
-ParameterPattern::VelocityPatterns(_VelocityPatterns, _EndVelocityPatterns);
+ParameterPattern::VelocityPatterns(velocityPatternsArray, endVelocityPatterns);
 
-ParameterPattern * _ControllerPatterns[] = {
+ParameterPattern * controllerPatternsArray[] = {
     &LinearParameterPattern::crescendo,
     &LinearParameterPattern::diminuendo,
     &IncreaseParameterPattern::decrease,
@@ -111,7 +111,7 @@ ParameterPattern * _ControllerPatterns[] = {
     &RelativeRamp::single,
 };
 
-DEFINE_PPVEC_FROM_ARRAY(ControllerPatterns, _ControllerPatterns);
+DEFINE_PPVEC_FROM_ARRAY(ControllerPatterns, controllerPatternsArray);
 
 /* ***** Helper functions ***** */
    
