@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _SELECTIONSITUATION_H_
-#define _SELECTIONSITUATION_H_
+#ifndef RG_SELECTIONSITUATION_H
+#define RG_SELECTIONSITUATION_H
 
 #include "base/PropertyName.h"
 #include "base/Selection.h"
@@ -74,4 +74,4 @@ class SelectionSituation
 
 }
 
-#endif /* ifndef _SELECTIONSITUATION_H_ */
+#endif /* ifndef RG_SELECTIONSITUATION_H */
