@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -44,7 +44,7 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
     m_relayoutEndTime(getEndTime()),
     m_clipboard(new Clipboard(*clipboard)),
     m_pasteType(pasteType),
-    m_pastedEvents()
+    m_pastedEvents(segment)
 {
     if (pasteType != OpenAndPaste) {
 
@@ -73,7 +73,7 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
     m_relayoutEndTime(getEndTime()),
     m_clipboard(new Clipboard(*clipboard)),
     m_pasteType(pasteType),
-    m_pastedEvents()
+    m_pastedEvents(segment)
 {}
 
 PasteEventsCommand::~PasteEventsCommand()
@@ -229,7 +229,7 @@ PasteEventsCommand::modifySegment()
 
             for (size_t i = 0; i < copies.size(); ++i) {
                 destination->insert(copies[i]);
-                m_pastedEvents.push_back(copies[i]);
+                m_pastedEvents.addEvent(copies[i]);
             }
 
             break;
@@ -248,10 +248,10 @@ PasteEventsCommand::modifySegment()
                 // e is model event: we retain ownership of it
                 Segment::iterator i = helper.insertNote(e);
                 delete e;
-                if (i != destination->end()) m_pastedEvents.push_back(*i);
+                if (i != destination->end()) m_pastedEvents.addEvent(*i);
             } else {
                 destination->insert(e);
-                m_pastedEvents.push_back(e);
+                m_pastedEvents.addEvent(e);
             }
         }
 
@@ -280,10 +280,15 @@ PasteEventsCommand::modifySegment()
             }
 
             destination->insert(e);
-            m_pastedEvents.push_back(e);
+            m_pastedEvents.addEvent(e);
         }
 
-        destination->normalizeRests(pasteTime, pasteTime + duration);
+//        destination->normalizeRests(pasteTime, pasteTime + duration);
+ 
+        // We ran the normalizeRests() calls like this as far back as I can go
+        // in history, and since normalizeRests() has been implicated in a
+        // string of recent paste bugs, we're going with the historical version: 
+        destination->normalizeRests(source->getStartTime(), source->getEndTime());
 
         return ;
     }
@@ -298,22 +303,22 @@ PasteEventsCommand::modifySegment()
                                               <Int>(BEAMED_GROUP_ID)]);
         }
         destination->insert(e);
-        m_pastedEvents.push_back(e);
+        m_pastedEvents.addEvent(e);
     }
 
-    destination->normalizeRests(pasteTime, pasteTime + duration);
+//    destination->normalizeRests(pasteTime, pasteTime + duration);
+
+
+    // We ran the normalizeRests() calls like this as far back as I can go
+    // in history, and since normalizeRests() has been implicated in a
+    // string of recent paste bugs, we're going with the historical version: 
+    destination->normalizeRests(source->getStartTime(), source->getEndTime());
 }
 
-EventSelection *
-PasteEventsCommand::getSubsequentSelection()
+EventSelection
+PasteEventsCommand::getPastedEvents()
 {
-    EventSelection *selection = new EventSelection(getSegment());
-    for (EventVec::const_iterator i = m_pastedEvents.begin();
-         i != m_pastedEvents.end();
-         ++i) {
-        selection->addEvent(*i);
-    }
-    return selection;
-}    
+    return m_pastedEvents;
+}
 
 }
