@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,18 +16,18 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_PASTEEVENTSCOMMAND_H_
-#define _RG_PASTEEVENTSCOMMAND_H_
+#ifndef RG_PASTEEVENTSCOMMAND_H
+#define RG_PASTEEVENTSCOMMAND_H
 
 #include "document/BasicCommand.h"
 #include "base/Selection.h"
-#include "base/Event.h"
-
+#include <map>
 #include <QString>
+#include "base/Event.h"
 #include <QCoreApplication>
 
-#include <map>
-#include <vector>
+
+
 
 namespace Rosegarden
 {
@@ -54,8 +54,6 @@ public:
     typedef std::map<PasteType, QString> PasteTypeMap;
     static PasteTypeMap getPasteTypes(); // type, descrip
 
-    typedef std::vector<Event*> EventVec;
-
     /**
      * Construct a Paste command from a clipboard that already contains
      * the events to be pasted.
@@ -82,7 +80,7 @@ public:
 
     virtual ~PasteEventsCommand();
 
-    EventSelection * getSubsequentSelection();
+    EventSelection getPastedEvents();
 
     static QString getGlobalName() { return tr("&Paste"); }
 
@@ -99,7 +97,7 @@ protected:
     timeT m_relayoutEndTime;
     Clipboard *m_clipboard;
     PasteType m_pasteType;
-    EventVec m_pastedEvents;
+    EventSelection m_pastedEvents;
 };
 
 
