@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -21,6 +21,8 @@
 #include "base/Segment.h"
 #include "gui/rulers/ControllerEventAdapter.h"
 
+#include <QtGlobal>
+
 namespace Rosegarden
 {
 
@@ -41,7 +43,7 @@ int
 PlaceControllersCommand::getDefaultValue(const Instrument *instrument,
                                          const ControlParameter *cp)
 {
-    assert(cp);
+    Q_CHECK_PTR(cp);
     if (cp->getType() == Controller::EventType)
         // For controllers, use the static value if there is one.
         {
