@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,8 +16,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_REMOVEMARKSCOMMAND_H_
-#define _RG_REMOVEMARKSCOMMAND_H_
+#ifndef RG_REMOVEMARKSCOMMAND_H
+#define RG_REMOVEMARKSCOMMAND_H
 
 #include "document/BasicSelectionCommand.h"
 #include <QString>
