@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -704,6 +704,14 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             getComposition().setEndMarker(endMarkerStr.toInt());
         }
 
+        QString autoExpand = atts.value("autoExpand");
+        if (!autoExpand.isEmpty()) {
+            if (autoExpand.toInt() == 1)
+                getComposition().setAutoExpand(true);
+            else
+                getComposition().setAutoExpand(false);
+        }
+
         QString panLawStr = atts.value("panlaw");
         if (!panLawStr.isEmpty()) {
             int panLaw = panLawStr.toInt();
