@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_XMLSUBHANDLER_H_
-#define _RG_XMLSUBHANDLER_H_
+#ifndef RG_XMLSUBHANDLER_H
+#define RG_XMLSUBHANDLER_H
 
 #include <QString>
 #include <qxml.h>
@@ -48,4 +48,4 @@ public:
 
 }
 
-#endif /*_RG_XMLSUBHANDLER_H_*/
+#endif /*RG_XMLSUBHANDLER_H*/
