@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This file is Copyright 2002
         Hans Kieserman      <hkieserman@mail.com>
@@ -26,8 +26,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_LILYPONDEXPORTER_H_
-#define _RG_LILYPONDEXPORTER_H_
+#ifndef RG_LILYPONDEXPORTER_H
+#define RG_LILYPONDEXPORTER_H
 
 #include "base/Event.h"
 #include "base/PropertyName.h"
@@ -248,6 +248,7 @@ private:
         LILYPOND_VERSION_2_8,
         LILYPOND_VERSION_2_10,
         LILYPOND_VERSION_2_12,
+        LILYPOND_VERSION_2_14
     };
 
     int m_repeatMode;
@@ -259,6 +260,7 @@ private:
 
     bool m_voltaBar;
     bool m_cancelAccidentals;
+    bool m_fingeringsInStaff;
     QString m_warningMessage;
 
     std::pair<int,int> fractionSum(std::pair<int,int> x,std::pair<int,int> y) {
