@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,8 +16,8 @@
 */
 
 
-#ifndef _LILYPOND_SEGMENTS_CONTEXT_H_
-#define _LILYPOND_SEGMENTS_CONTEXT_H_
+#ifndef RG_LILYPOND_SEGMENTS_CONTEXT_H
+#define RG_LILYPOND_SEGMENTS_CONTEXT_H
 
 /*
  * LilyPondSegmentsContext.h
@@ -307,4 +307,4 @@ private :
 
 }
 
-#endif // _LILYPOND_SEGMENTS_CONTEXT_H_
+#endif // RG_LILYPOND_SEGMENTS_CONTEXT_H
