@@ -34,7 +34,7 @@
 #include "base/Track.h"
 
 #include <QString>
-#include <assert.h>
+#include <QtGlobal>
 
 namespace Rosegarden
 
@@ -369,6 +369,9 @@ MusicXMLXMLHandler::startPartList(const QString& qName,
         // These elements get ignored
     } else if (m_currentElement == "midi-instrument") {
         ret = getAttributeString(atts, "id", m_midiInstrument);
+    } else if ((m_currentElement == "volume") ||
+              (m_currentElement == "pan")) {
+        //  Probably could be supported, but far easier to ignore
     } else if ((m_currentElement == "part-name") ||
             (m_currentElement == "midi-channel") ||
             (m_currentElement == "midi-program") ||
@@ -377,7 +380,18 @@ MusicXMLXMLHandler::startPartList(const QString& qName,
         // processed via endElement().
     } else {
         // For debugging
-        assert(0);
+        RG_DEBUG << "MusicXMLXMLHandler::startPartList: cannot process element \'"
+                 << m_currentElement
+                 << "\'"
+                 << endl;
+        // I did a test in a clean bash environment (no extra environment
+        // variables)  with a clean release build, and Rosegarden crashed on
+        // this assert.  I added -DQT_NO_DEBUG_OUTPUT and -dQT_NO_WARNING_OUTPUT
+        // to configure.ac, did another clean release build, and Rosegarden
+        // continued to crash on this assert.  According to the Qt API docs that
+        // should not be, but it is.  Plainly it is not safe to use Q_ASSERT in
+        // production code.
+        //Q_ASSERT(0);
     }
     
     return ret;
@@ -399,13 +413,13 @@ MusicXMLXMLHandler::endPartList(const QString& qName)
             if (m_brace == 0) {
                 m_brace = m_number;
             } else {
-                cerrWarning("Overlapping braces are not support, this brace is ignored!");
+                cerrWarning("Overlapping braces are not supported, this brace is ignored!");
             }
         } else if (m_characters.toLower() == "bracket") {
             if (m_bracket == 0) {
                 m_bracket = m_number;
             } else {
-                cerrWarning("Overlapping brackets are not support, this bracket is ignored!");
+                cerrWarning("Overlapping brackets are not supported, this bracket is ignored!");
             }
         } else {
             cerrWarning(QString("group-symbol \"%1\" not supported, ignored.").arg(m_characters));
