@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This file is Copyright 2005
         Toni Arnold         <toni__arnold@bluewin.ch>
@@ -18,8 +18,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_LIRCCOMMANDER_H_
-#define _RG_LIRCCOMMANDER_H_
+#ifndef RG_LIRCCOMMANDER_H
+#define RG_LIRCCOMMANDER_H
 
 #ifdef HAVE_LIRC
 
