@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -148,29 +148,29 @@ RosegardenMainViewWidget::RosegardenMainViewWidget(bool showTrackLabels,
             SIGNAL(editSegment(Segment*)),
             SLOT(slotEditSegment(Segment*)));
 
-    connect(m_trackEditor->getCompositionView(),
-            SIGNAL(editSegmentNotation(Segment*)),
-            SLOT(slotEditSegmentNotation(Segment*)));
+    //connect(m_trackEditor->getCompositionView(),
+    //        SIGNAL(editSegmentNotation(Segment*)),
+    //        SLOT(slotEditSegmentNotation(Segment*)));
 
-    connect(m_trackEditor->getCompositionView(),
-            SIGNAL(editSegmentPitchView(Segment*)),
-            SLOT(slotEditSegmentPitchView(Segment*)));
+    //connect(m_trackEditor->getCompositionView(),
+    //        SIGNAL(editSegmentPitchView(Segment*)),
+    //        SLOT(slotEditSegmentPitchView(Segment*)));
 
-    connect(m_trackEditor->getCompositionView(),
-            SIGNAL(editSegmentMatrix(Segment*)),
-            SLOT(slotEditSegmentMatrix(Segment*)));
+    //connect(m_trackEditor->getCompositionView(),
+    //        SIGNAL(editSegmentMatrix(Segment*)),
+    //        SLOT(slotEditSegmentMatrix(Segment*)));
 
-    connect(m_trackEditor->getCompositionView(),
-            SIGNAL(editSegmentAudio(Segment*)),
-            SLOT(slotEditSegmentAudio(Segment*)));
+    //connect(m_trackEditor->getCompositionView(),
+    //        SIGNAL(editSegmentAudio(Segment*)),
+    //        SLOT(slotEditSegmentAudio(Segment*)));
 
-    connect(m_trackEditor->getCompositionView(),
-            SIGNAL(audioSegmentAutoSplit(Segment*)),
-            SLOT(slotSegmentAutoSplit(Segment*)));
+    //connect(m_trackEditor->getCompositionView(),
+    //        SIGNAL(audioSegmentAutoSplit(Segment*)),
+    //        SLOT(slotSegmentAutoSplit(Segment*)));
 
-    connect(m_trackEditor->getCompositionView(),
-            SIGNAL(editSegmentEventList(Segment*)),
-            SLOT(slotEditSegmentEventList(Segment*)));
+    //connect(m_trackEditor->getCompositionView(),
+    //        SIGNAL(editSegmentEventList(Segment*)),
+    //        SLOT(slotEditSegmentEventList(Segment*)));
 
     connect(m_trackEditor->getCompositionView(),
             SIGNAL(editRepeat(Segment*, timeT)),
@@ -228,7 +228,7 @@ RosegardenMainViewWidget::RosegardenMainViewWidget(bool showTrackLabels,
 
         QObject::connect
         (CommandHistory::getInstance(), SIGNAL(commandExecuted()),
-         m_trackEditor->getCompositionView(), SLOT(slotUpdateSegmentsDrawBuffer()));
+         m_trackEditor->getCompositionView(), SLOT(slotUpdateAll()));
     }
 }
 
@@ -466,12 +466,12 @@ RosegardenMainViewWidget::createNotationView(std::vector<Segment *> segmentsToEd
     connect(notationView, SIGNAL(editTriggerSegment(int)),
             this, SLOT(slotEditTriggerSegment(int)));
     // No such signal comes from NotationView
-//    connect(notationView, SIGNAL(staffLabelChanged(TrackId, QString)),
-//            this, SLOT(slotChangeTrackLabel(TrackId, QString)));
+    //connect(notationView, SIGNAL(staffLabelChanged(TrackId, QString)),
+    //        this, SLOT(slotChangeTrackLabel(TrackId, QString)));
     connect(notationView, SIGNAL(toggleSolo(bool)),
             RosegardenMainWindow::self(), SLOT(slotToggleSolo(bool)));
-    connect(notationView, SIGNAL(editTimeSignature(timeT)),
-            RosegardenMainWindow::self(), SLOT(slotEditTempos(timeT)));
+    //connect(notationView, SIGNAL(editTimeSignature(timeT)),
+    //        RosegardenMainWindow::self(), SLOT(slotEditTempos(timeT)));
 
     SequenceManager *sM = getDocument()->getSequenceManager();
 
@@ -641,12 +641,12 @@ RosegardenMainViewWidget::createPitchTrackerView(std::vector<Segment *> segments
     connect(pitchTrackerView, SIGNAL(editTriggerSegment(int)),
             this, SLOT(slotEditTriggerSegment(int)));
     // No such signal comes from PitchTrackerView
-//    connect(pitchTrackerView, SIGNAL(staffLabelChanged(TrackId, QString)),
-//            this, SLOT(slotChangeTrackLabel(TrackId, QString)));
+    //connect(pitchTrackerView, SIGNAL(staffLabelChanged(TrackId, QString)),
+    //        this, SLOT(slotChangeTrackLabel(TrackId, QString)));
     connect(pitchTrackerView, SIGNAL(toggleSolo(bool)),
             RosegardenMainWindow::self(), SLOT(slotToggleSolo(bool)));
-    connect(pitchTrackerView, SIGNAL(editTimeSignature(timeT)),
-            RosegardenMainWindow::self(), SLOT(slotEditTempos(timeT)));
+    //connect(pitchTrackerView, SIGNAL(editTimeSignature(timeT)),
+    //        RosegardenMainWindow::self(), SLOT(slotEditTempos(timeT)));
 
     SequenceManager *sM = getDocument()->getSequenceManager();
 
@@ -850,8 +850,8 @@ RosegardenMainViewWidget::createMatrixView(std::vector<Segment *> segmentsToEdit
             this, SLOT(slotEditTriggerSegment(int)));
     connect(matrixView, SIGNAL(toggleSolo(bool)),
             RosegardenMainWindow::self(), SLOT(slotToggleSolo(bool)));
-    connect(matrixView, SIGNAL(editTimeSignature(timeT)),
-            RosegardenMainWindow::self(), SLOT(slotEditTempos(timeT)));
+    //connect(matrixView, SIGNAL(editTimeSignature(timeT)),
+    //        RosegardenMainWindow::self(), SLOT(slotEditTempos(timeT)));
 
     SequenceManager *sM = getDocument()->getSequenceManager();
 
@@ -1795,7 +1795,7 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
 
     // from qt4-doc : " don't use a (modal) QProgressDialog inside a paintEvent() !"
 
-    //cc 20130508: because ProgressDialog has WA_DeleteOnClose set, it
+    //cc 20140508: because ProgressDialog has WA_DeleteOnClose set, it
     // is destroyed if the user closes it during event processing --
     // use a QPointer to avoid dereferencing it afterwards
     QPointer<ProgressDialog> progressDlg =
