@@ -2,7 +2,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -13,8 +13,8 @@
 */
 
 
-#ifndef _ROSEGARDEN_TRANSPORT_STATUS_H_
-#define _ROSEGARDEN_TRANSPORT_STATUS_H_
+#ifndef RG_TRANSPORT_STATUS_H
+#define RG_TRANSPORT_STATUS_H
 
 typedef enum
 {
@@ -28,5 +28,5 @@ typedef enum
      QUIT
 } TransportStatus;
 
-#endif // _ROSEGARDEN_TRANSPORT_STATUS_H_
+#endif // RG_TRANSPORT_STATUS_H
 
