@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     This file is Copyright 2009
         Immanuel Litzroth         <immanuel203@gmail.com>
@@ -149,11 +149,11 @@ TranzportClient::pointerPositionChanged(timeT time)
 }
 
 void
-TranzportClient::documentChanged(RosegardenDocument* m_doc)
+TranzportClient::documentChanged(RosegardenDocument* doc)
 {
     RG_DEBUG << "TranzportClient::DocumentChanged " << endl;
 
-    m_rgDocument = m_doc;
+    m_rgDocument = doc;
     m_composition = &m_rgDocument->getComposition();
     m_composition->addObserver(this);
     connect(m_rgDocument, SIGNAL(pointerPositionChanged(timeT)),
