@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -24,6 +24,7 @@
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QSpinBox>
+#include <QCheckBox>
 #include <QWidget>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -58,46 +59,44 @@ CompositionLengthDialog::CompositionLengthDialog(
 
     vboxLayout->addWidget(new QLabel(tr("Change the start and end markers for the composition:")));
 
+    // GROUP BOX BEGIN
+
     QGroupBox *gbox = new QGroupBox(this);
     vboxLayout->addWidget(gbox);
 
-    QVBoxLayout *gboxLayout = new QVBoxLayout;
+    QGridLayout *gboxLayout = new QGridLayout;
+    gboxLayout->setVerticalSpacing(10);
     gbox->setLayout(gboxLayout);
 
-    // Since we want to stack two hbox layouts in a vbox layout (inside a group
-    // box inside another vbox layout), we do have to create a QWidget here.
-    // This is the widget/hbox combo for the top set of controls:
-    QWidget *startBox = new QWidget(gbox);
-    QHBoxLayout *startBoxLayout = new QHBoxLayout;
-    startBox->setLayout(startBoxLayout);
+    // ROW 0, Start Bar
 
-    gboxLayout->addWidget(startBox);
-    
-    startBoxLayout->addWidget(new QLabel(tr("Start Bar")), Qt::AlignLeft);
+    gboxLayout->addWidget(new QLabel(tr("Start Bar")), 0, 0);
 
-    m_startMarkerSpinBox = new QSpinBox(startBox);
+    m_startMarkerSpinBox = new QSpinBox(gbox);
     m_startMarkerSpinBox->setMinimum( -10);
     m_startMarkerSpinBox->setMaximum(10000);
     m_startMarkerSpinBox->setValue(m_composition->getBarNumber(m_composition->getStartMarker()) + 1);
-    startBoxLayout->addWidget(m_startMarkerSpinBox);
+    gboxLayout->addWidget(m_startMarkerSpinBox, 0, 1);
 
-    // Now we need another widget/hbox for the bottom set of controls (or I
-    // guess we could have laid everything out on a grid layout inside the combo
-    // box, in retrospect, but whatever.  This works.  This is the bottom set of
-    // controls:
-    QWidget *endBox = new QWidget(gbox);
-    QHBoxLayout *endBoxLayout = new QHBoxLayout;
-    endBox->setLayout(endBoxLayout);
+    // ROW 1, End Bar
 
-    gboxLayout->addWidget(endBox);
+    gboxLayout->addWidget(new QLabel(tr("End Bar")), 1, 0);
 
-    endBoxLayout->addWidget(new QLabel(tr("End Bar")), Qt::AlignLeft);
-
-    m_endMarkerSpinBox = new QSpinBox(endBox);
+    m_endMarkerSpinBox = new QSpinBox(gbox);
     m_endMarkerSpinBox->setMinimum( -10);
     m_endMarkerSpinBox->setMaximum(10000);
     m_endMarkerSpinBox->setValue(m_composition->getBarNumber(m_composition->getEndMarker()));
-    endBoxLayout->addWidget(m_endMarkerSpinBox);
+    gboxLayout->addWidget(m_endMarkerSpinBox, 1, 1);
+
+    // ROW 2, Auto-Expand when Editing
+
+    gboxLayout->addWidget(new QLabel(tr("Auto-Expand when Editing")), 2, 0);
+
+    m_autoExpandCheckBox = new QCheckBox(gbox);
+    m_autoExpandCheckBox->setChecked(m_composition->autoExpandEnabled());
+    gboxLayout->addWidget(m_autoExpandCheckBox, 2, 1);
+    
+    // GROUP BOX END
 
     // Now the button box on the bottom, outside the group box and any of the
     // previous layouts, just gets added to the vbox under the QDialog widget
@@ -121,5 +120,11 @@ CompositionLengthDialog::getEndMarker()
     return m_composition->getBarStart(m_endMarkerSpinBox->value());
 }
 
+bool
+CompositionLengthDialog::autoExpandEnabled()
+{
+    return m_autoExpandCheckBox->isChecked();
+}
+
 }
 #include "CompositionLengthDialog.moc"
