@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -62,8 +62,9 @@ ConfigureDialog::ConfigureDialog(RosegardenDocument *doc,
 
     connect(page, SIGNAL(updateAutoSaveInterval(unsigned int)),
             this, SIGNAL(updateAutoSaveInterval(unsigned int)));
-    connect(page, SIGNAL(updateSidebarStyle(unsigned int)),
-            this, SIGNAL(updateSidebarStyle(unsigned int)));
+    // No such signal in GeneralConfigurationPage.
+    //connect(page, SIGNAL(updateSidebarStyle(unsigned int)),
+    //        this, SIGNAL(updateSidebarStyle(unsigned int)));
 
     page = new MIDIConfigurationPage(doc, this);
     connect(page,SIGNAL(modified()),this,SLOT(slotActivateApply()));
