@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_LILYPONDOPTIONSDIALOG_H_
-#define _RG_LILYPONDOPTIONSDIALOG_H_
+#ifndef RG_LILYPONDOPTIONSDIALOG_H
+#define RG_LILYPONDOPTIONSDIALOG_H
 
 #include <QDialog>
 #include <QString>
@@ -73,6 +73,7 @@ protected:
     QCheckBox *m_lilyRepeatMode;
     QCheckBox *m_lilyDrawBarAtVolta;
     QCheckBox *m_cancelAccidentals;
+    QCheckBox *m_fingeringsInStaff;
     HeadersConfigurationPage *m_headersPage;
 
     // Used to add the "edited segments" option when the dialog is opened
