@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -42,8 +42,8 @@
 #include <QCloseEvent>
 #include <QUrl>
 #include <QDesktopServices>
+#include <QtGlobal>
 
-#include <cassert>
 #include <cmath>
 
 namespace Rosegarden
@@ -120,7 +120,11 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
 
         vboxLayout->addSpacing(15);
 
-    
+        // Preset can change what's shown, which normally stretches
+        // the layout and thus moves preset out from under the user's
+        // mouse.  To avoid this, we call `vboxLayout->addStretch'
+        // generously after this point in the layout and never call it
+        // before this point.
 
         QGroupBox *presetBox = new QGroupBox(tr("Preset"));
         QGridLayout *presetGrid = new QGridLayout;
@@ -149,6 +153,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             }
         m_sequencePreset->setCurrentIndex(settings.value("sequence_preset", int(startSavedSettings)).toInt());
 
+        vboxLayout->addStretch(15);
+
         QString prebendText =
             (whatVaries == Pitch) ?
             tr("Pre Bend") :
@@ -163,8 +169,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             useTrueValues() ?
             tr("Start at value:") :
             tr("Start at value (%):");
-        prebendGrid->addWidget(new QLabel(prebendValueText, prebendBox), 0, 0);
-        m_prebendValue = new QDoubleSpinBox(prebendBox);
+        prebendGrid->addWidget(new QLabel(prebendValueText), 0, 0);
+        m_prebendValue = new QDoubleSpinBox();
         m_prebendValue->setAccelerated(true);
         m_prebendValue->setMaximum(maxSpinboxValue);
         m_prebendValue->setMinimum(minSpinboxValue);
@@ -174,23 +180,24 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
     
         prebendBox->setLayout(prebendGrid);
 
-        QLabel *durationLabel = new QLabel(tr("Wait (%):"),
-                                           prebendBox);
+        QLabel *durationLabel = new QLabel(tr("Wait (%):"));
         durationLabel->
             setToolTip(tr("<qt>How long to wait before starting the bend or ramp, as a percentage of the total time</qt>"));
         prebendGrid->addWidget(durationLabel, 1, 0);
-        m_prebendDuration = new QDoubleSpinBox(prebendBox);
+        m_prebendDuration = new QDoubleSpinBox();
         m_prebendDuration->setAccelerated(true);
         m_prebendDuration->setMaximum(100);
         m_prebendDuration->setMinimum(0);
         m_prebendDuration->setSingleStep(5);
         prebendGrid->addWidget(m_prebendDuration, 1 , 1);
 
+        vboxLayout->addStretch(15);
+
         QString sequenceText =
             (whatVaries == Pitch) ?
             tr("Bend Sequence") :
             tr("Ramp Sequence");
-        QGroupBox *sequencebox = new QGroupBox(sequenceText, vbox );
+        QGroupBox *sequencebox = new QGroupBox(sequenceText);
         sequencebox->setContentsMargins(5, 5, 5, 5);
         QGridLayout *sequencegrid = new QGridLayout;
         sequencegrid->setSpacing(5);
@@ -202,11 +209,11 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             tr("Bend duration (%):") :
             tr("Ramp duration (%):");
         QLabel *sequenceDurationLabel =
-            new QLabel(sequenceDurationText, sequencebox);
+            new QLabel(sequenceDurationText);
         sequenceDurationLabel->
             setToolTip(tr("<qt>How long the bend or ramp lasts, as a percentage of the remaining time</qt>"));
         sequencegrid->addWidget(sequenceDurationLabel, 1, 0);
-        m_sequenceRampDuration = new QDoubleSpinBox(sequencebox);
+        m_sequenceRampDuration = new QDoubleSpinBox();
         m_sequenceRampDuration->setAccelerated(true);
         m_sequenceRampDuration->setMaximum(100);
         m_sequenceRampDuration->setMinimum(0);
@@ -217,8 +224,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             useTrueValues() ?
             tr("End value:") :
             tr("End value (%):");
-        sequencegrid->addWidget(new QLabel(sequenceEndValueText, sequencebox), 2, 0);
-        m_sequenceEndValue = new QDoubleSpinBox(sequencebox);
+        sequencegrid->addWidget(new QLabel(sequenceEndValueText), 2, 0);
+        m_sequenceEndValue = new QDoubleSpinBox();
         m_sequenceEndValue->setAccelerated(true);
         m_sequenceEndValue->setMaximum(maxSpinboxValue);
         m_sequenceEndValue->setMinimum(minSpinboxValue);
@@ -226,13 +233,15 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
         m_sequenceEndValue->setSingleStep(5);
         sequencegrid->addWidget(m_sequenceEndValue, 2, 1);
 
+        vboxLayout->addStretch(15);
+
         /*** Sub-group vibrato ****/
 
         QString vibratoBoxText =
             (whatVaries == Pitch)  ? tr("Vibrato") :
             (whatVaries == Volume) ? tr("Tremolo") :
             tr("LFO");
-        QGroupBox *m_vibratoBox = new QGroupBox(vibratoBoxText, vbox );
+        m_vibratoBox = new QGroupBox(vibratoBoxText);
         m_vibratoBox->
             setToolTip(tr("<qt>Low-frequency oscillation for this controller. This is only possible when Ramp mode is linear and <i>Use this many steps</i> is set.</qt>"));
         m_vibratoBox->setContentsMargins(5, 5, 5, 5);
@@ -245,9 +254,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             useTrueValues() ?
             tr("Start amplitude:") :
             tr("Start amplitude (%):");
-        vibratoGrid->addWidget(new QLabel(vibratoStartAmplitudeText, 
-                                           m_vibratoBox), 3, 0);
-        m_vibratoStartAmplitude = new QDoubleSpinBox(m_vibratoBox);
+        vibratoGrid->addWidget(new QLabel(vibratoStartAmplitudeText), 3, 0);
+        m_vibratoStartAmplitude = new QDoubleSpinBox();
         m_vibratoStartAmplitude->setAccelerated(true);
         m_vibratoStartAmplitude->setMaximum(maxSpinboxAbsValue);
         m_vibratoStartAmplitude->setMinimum(0);
@@ -258,9 +266,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             useTrueValues() ?
             tr("End amplitude:") :
             tr("End amplitude (%):");
-        vibratoGrid->addWidget(new QLabel(vibratoEndAmplitudeText,
-                                           m_vibratoBox), 4, 0);
-        m_vibratoEndAmplitude = new QDoubleSpinBox(m_vibratoBox);
+        vibratoGrid->addWidget(new QLabel(vibratoEndAmplitudeText), 4, 0);
+        m_vibratoEndAmplitude = new QDoubleSpinBox();
         m_vibratoEndAmplitude->setAccelerated(true);
         m_vibratoEndAmplitude->setMaximum(maxSpinboxAbsValue);
         m_vibratoEndAmplitude->setMinimum(0);
@@ -268,11 +275,11 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
         vibratoGrid->addWidget(m_vibratoEndAmplitude, 4, 1);
 
         QLabel * vibratoFrequencyLabel =
-            new QLabel(tr("Hertz (Hz):"), m_vibratoBox);
+            new QLabel(tr("Hertz (Hz):"));
         vibratoFrequencyLabel->
             setToolTip(tr("<qt>Frequency in hertz (cycles per second)</qt>"));
         vibratoGrid->addWidget(vibratoFrequencyLabel, 5, 0);
-        m_vibratoFrequency = new QDoubleSpinBox(m_vibratoBox);
+        m_vibratoFrequency = new QDoubleSpinBox();
         m_vibratoFrequency->setAccelerated(true);
         m_vibratoFrequency->setMaximum(200);
         m_vibratoFrequency->setMinimum(0.1);
@@ -280,6 +287,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
         m_vibratoFrequency->setDecimals(2);
         vibratoGrid->addWidget(m_vibratoFrequency, 5, 1);
         
+        vboxLayout->addStretch(15);
+
         /*** Sub-group the contour of the ramp ****/
         
         QGroupBox *rampModeGroupBox = new QGroupBox(tr("Ramp mode"));
@@ -305,6 +314,8 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
         rampModeGroupLayoutBox->addWidget(m_radioRampQuarterSine);
         rampModeGroupLayoutBox->addWidget(m_radioRampHalfSine);
         
+        vboxLayout->addStretch(15);
+
         /*** Sub-group how we set step size or step count ****/
 
         QGroupBox *stepSizeStyleGroupBox =
@@ -320,7 +331,7 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
             setToolTip(tr("<qt>The sequence will have exactly this many steps.  Vibrato is possible if Ramp mode is linear</qt>"));
         
         /* Stepsize -> direct -> step size */
-        m_stepSize = new QDoubleSpinBox(stepSizeStyleGroupBox);
+        m_stepSize = new QDoubleSpinBox();
         m_stepSize->setAccelerated(true);
         m_stepSize->setMaximum(maxSpinboxAbsValue);
         m_stepSize->setMinimum(getSmallestSpinboxStep());
@@ -333,7 +344,7 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
         stepSizeManualHBox->addWidget(m_stepSize);
 
         /* Stepsize -> by count -> Resolution */        
-        m_resolution = new QDoubleSpinBox(stepSizeStyleGroupBox);
+        m_resolution = new QDoubleSpinBox();
         m_resolution->setAccelerated(true);
         m_resolution->setMaximum(300);
         m_resolution->setMinimum(2);
@@ -352,10 +363,12 @@ PitchBendSequenceDialog::PitchBendSequenceDialog(QWidget *parent,
         stepSizeStyleGroupLayoutBox->addLayout(stepSizeManualHBox);
         stepSizeStyleGroupLayoutBox->addLayout(stepSizeByCountHBox);
 
+        vboxLayout->addStretch(15);
+
         
         slotSequencePresetChanged(m_sequencePreset->currentIndex());
-        slotStepSizeStyleChanged(true);
-        maybeEnableVibratoFields();
+        // the above called slotStepSizeStyleChanged() which called
+        // maybeEnableVibratoFields()
         m_radioReplace->setChecked(true);
 
         connect(m_sequencePreset, SIGNAL(activated(int)), this,
@@ -416,7 +429,7 @@ PitchBendSequenceDialog::slotOnlyEraseClicked(bool checked)
         m_vibratoFrequency->setEnabled(false);
     } else {
         slotStepSizeStyleChanged(true);
-        maybeEnableVibratoFields();
+        //maybeEnableVibratoFields();
     }
 }
 
@@ -427,10 +440,7 @@ PitchBendSequenceDialog::maybeEnableVibratoFields(void)
         m_radioRampLinear->isChecked() &&
         m_radioStepSizeByCount->isChecked();
     
-    m_vibratoStartAmplitude->setEnabled(enable);
-    m_vibratoEndAmplitude->setEnabled(enable);
-    m_vibratoFrequency->setEnabled(enable);
-    // show()/hide() on m_vibratoBox is buggy so we don't use it.
+    m_vibratoBox->setVisible(enable);
 }
 
 void
@@ -498,7 +508,7 @@ PitchBendSequenceDialog::slotSequencePresetChanged(int index) {
         }
     }
     slotStepSizeStyleChanged(true);
-    maybeEnableVibratoFields();
+    // the above called maybeEnableVibratoFields();
 }
 
 bool
@@ -689,6 +699,7 @@ PitchBendSequenceDialog::savePreset(int preset)
     settings.setValue("step_size", m_stepSize->value());
     settings.setValue("ramp_mode", getRampMode());
     settings.setValue("step_size_calculation", getStepSizeCalculation());
+    settings.endArray();
     settings.endGroup();
 }
 
@@ -718,6 +729,7 @@ PitchBendSequenceDialog::restorePreset(int preset)
         (StepSizeCalculation
          (settings.value("step_size_calculation", StepSizeDirect).toInt()));
 
+    settings.endArray();
     settings.endGroup();
 }
 
@@ -729,7 +741,8 @@ PitchBendSequenceDialog::accept()
 
     // We don't enable "OK" if the interval isn't sensible, so
     // something's badly wrong if this test fails.
-    assert(m_startTime < m_endTime);
+    Q_ASSERT_X(m_startTime < m_endTime, "accept",
+             "got a zero or negative time interval");
 
     /* Save current settings.  They'll be the defaults next time. */
     saveSettings();
@@ -895,7 +908,7 @@ PitchBendSequenceDialog::addStepwiseEvents(MacroCommand *macro)
         {
             const int rawStepSize = spinboxToControlDelta(m_stepSize);
             if (rawStepSize == 0) { return; }
-            numSteps = (float(valueChange) / float(rawStepSize) + 0.5);
+            numSteps = abs(float(valueChange) / float(rawStepSize) + 0.5);
             break;
         }
     }
@@ -1000,7 +1013,8 @@ PitchBendSequenceDialog::addStepwiseEvents(MacroCommand *macro)
                 // exactly zero, but since that once caused a serious
                 // bug let's always check it (If it's not exactly 0.0
                 // it wouldn't cause a divide-by-zero)
-                assert(denominator != 0.0);
+                Q_ASSERT_X(denominator != 0.0, "addStepwiseEvents",
+                           "got a denominator of exactly zero");
                 timeRatio = (
                              (log(startValue + epsilon + i * stepSize) - log(startValue + epsilon))
                              / denominator);
