@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -22,8 +22,8 @@
 /// replaces a series of such events in the a given segment.  It now
 /// supplies the functionality for several menu items.
 
-#ifndef _RG_PITCHBENDSEQUENCEDIALOG_H_
-#define _RG_PITCHBENDSEQUENCEDIALOG_H_
+#ifndef RG_PITCHBENDSEQUENCEDIALOG_H
+#define RG_PITCHBENDSEQUENCEDIALOG_H
 
 #include <QDialog>
 
