@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -17,8 +17,8 @@
 
 
 
-#ifndef _RG_FINGERINGBOX_H_
-#define _RG_FINGERINGBOX_H_
+#ifndef RG_FINGERINGBOX_H
+#define RG_FINGERINGBOX_H
 
 #include <QFrame>
 
@@ -112,4 +112,4 @@ protected:
 
 }
 
-#endif /*_RG_FINGERINGBOX2_H_*/
+#endif /*RG_FINGERINGBOX_H*/
