@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,8 +16,8 @@
 */
 
 
-#ifndef _RG_FINGERINGLISTBOXITEM_H_
-#define _RG_FINGERINGLISTBOXITEM_H_
+#ifndef RG_FINGERINGLISTBOXITEM_H
+#define RG_FINGERINGLISTBOXITEM_H
 
 #include "Chord.h"
 
@@ -41,4 +41,4 @@ protected:
 
 }
 
-#endif /*_RG_FINGERINGLISTBOXITEM_H_*/
+#endif /*RG_FINGERINGLISTBOXITEM_H*/
