@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This file contains code from 
     Other copyrights also apply to some parts of this work.  Please
@@ -17,8 +17,8 @@
 */
 
 
-#ifndef _RG_SYMBOLS_H_
-#define _RG_SYMBOLS_H_
+#ifndef RG_SYMBOLS_H
+#define RG_SYMBOLS_H
 
 #include <string>
 
