@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -15,8 +15,8 @@
 
 
 
-#ifndef _INCONSISTENCIES_H_
-#define _INCONSISTENCIES_H_
+#ifndef RG_INCONSISTENCIES_H
+#define RG_INCONSISTENCIES_H
 
 #include <vector>
 #include <map>
@@ -132,5 +132,5 @@ Inconsistencies<int>::getTranslatedName(int transpose) const
 
 }
 
-#endif // _INCONSISTENCIES_H_
+#endif // RG_INCONSISTENCIES_H
 
