@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -68,8 +68,8 @@ NotationSelector::NotationSelector(NotationWidget *widget, bool ties) :
     m_wholeStaffSelectionComplete(false),
     m_ties(ties)
 {
-    connect(m_widget, SIGNAL(usedSelection()),
-            this, SLOT(slotHideSelection()));
+    //connect(m_widget, SIGNAL(usedSelection()),
+    //        this, SLOT(slotHideSelection()));
 
     connect(this, SIGNAL(editElement(NotationStaff *, NotationElement *, bool)),
             m_widget, SIGNAL(editElement(NotationStaff *, NotationElement *, bool)));
