@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -91,8 +91,11 @@ NotationToolBox::createTool(QString toolName)
 
     if (m_scene) {
         tool->setScene(m_scene);
-        connect(m_scene, SIGNAL(eventRemoved(Event *)),
-                tool, SLOT(handleEventRemoved(Event *)));
+        // This would be great, if NotationTool had such a slot.  All
+        // of its derivers do.  This needs to be reworked and carefully
+        // tested to make sure it is doing what it should be doing.
+        //connect(m_scene, SIGNAL(eventRemoved(Event *)),
+        //        tool, SLOT(handleEventRemoved(Event *)));
     }
 
     return tool;
@@ -108,8 +111,11 @@ NotationToolBox::setScene(NotationScene *scene)
         NotationTool *nt = dynamic_cast<NotationTool *>(*i);
         if (nt) {
             nt->setScene(scene);
-            connect(scene, SIGNAL(eventRemoved(Event *)),
-                    nt, SLOT(handleEventRemoved(Event *)));
+            // This would be great, if NotationTool had such a slot.  All
+            // of its derivers do.  This needs to be reworked and carefully
+            // tested to make sure it is doing what it should be doing.
+            //connect(scene, SIGNAL(eventRemoved(Event *)),
+            //        nt, SLOT(handleEventRemoved(Event *)));
         }
     }
 }
