@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -45,6 +45,9 @@
 namespace Rosegarden
 {
 
+SystemFont::~SystemFont()
+{}
+
 SystemFont *
 SystemFont::loadSystemFont(const SystemFontSpec &spec)
 {
