@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -52,9 +52,11 @@ InstrumentParameterPanel::
 setSelectedInstrument(Instrument *instrument, QString label)
 {
     m_selectedInstrument = instrument;
-    // Make instrument tell us if it gets destroyed.
-    connect(instrument, SIGNAL(destroyed()),
-            this, SLOT(slotInstrumentGone()));
+    if (instrument) {
+        // Make instrument tell us if it gets destroyed.
+        connect(instrument, SIGNAL(destroyed()),
+                this, SLOT(slotInstrumentGone()));
+    }
     m_instrumentLabel->setText(label);
 }
 
