@@ -42,7 +42,10 @@
 #include <QAction>
 #include <QToolBar>
 #include <QToolButton>
+#include <QMenu>
+#include <QVector>
 
+#include <QDebug>
 
 namespace Rosegarden
 {
@@ -67,6 +70,11 @@ PitchTrackerView::PitchTrackerView(RosegardenDocument *doc,
                                  PitchDetector::defaultFrameSize).toInt();
     m_stepsize = settings.value("stepsize",
                                 PitchDetector::defaultStepSize).toInt();
+
+    int tuning = settings.value("tuning", 0).toInt();
+    int method = settings.value("method", 0).toInt();
+    settings.endGroup();
+
     // The frame size and step size are set from the default properties
     // of PitchDetector or by reading the settings file. In principle,
     // the latter method is open to attack by someone editing the settings
@@ -83,22 +91,25 @@ PitchTrackerView::PitchTrackerView(RosegardenDocument *doc,
     }
     
     // Find the current tuning index in use by the pitch tracker
-    int tuning = settings.value("tuning", 0).toInt();
     // The static method Tuning::getTunings() returns a pointer to a
     // std::vector of pointers to tunings. i.e.
     //     std::vector<Rosegarden::Accidentals::Tuning*>* getTunings(void);
     // The one we want is obtained be dereferencing the return value of
     // getTunings to obtain the std::vector, then indexing by the quantity
     // retreived above. So the following looks nasty, but that's C++ for you.
-    const std::vector<Accidentals::Tuning*>* availableTunings =
+    const std::vector<Accidentals::Tuning*> *availableTunings =
         Accidentals::Tuning::getTunings();
+    
     if (availableTunings) {
+        m_availableTunings =
+          QVector<Accidentals::Tuning*>::fromStdVector(*availableTunings);
+          
         if (tuning < 0 ||
             static_cast<unsigned int>(tuning) >= availableTunings->size()) {
             // Illegal index into available tunings (how??) -> use default.
             tuning = 0;
         }
-        m_tuning = (*availableTunings)[tuning];
+        m_tuning = m_availableTunings[tuning];
     } else {
         m_tuning = NULL;
         std::cout << "WARNING: No available tunings!" << std::endl;
@@ -127,13 +138,14 @@ PitchTrackerView::PitchTrackerView(RosegardenDocument *doc,
     int sampleRate = m_jackCaptureClient->getSampleRate();
 
     // pitch detector
-    int method = settings.value("method", 0).toInt();
     if (method < 0 or method > PitchDetector::getMethods()->size()) method = 0;
     PitchDetector::Method pdMethod = (*PitchDetector::getMethods())[method];
     m_pitchDetector = new PitchDetector(m_framesize, m_stepsize, sampleRate);
     m_pitchDetector->setMethod(pdMethod);
     
     setSegments(doc, segments);
+    
+    setupActions(tuning, method);
 }
 
 PitchTrackerView::~PitchTrackerView()
@@ -142,14 +154,78 @@ PitchTrackerView::~PitchTrackerView()
     if (m_jackCaptureClient) delete m_jackCaptureClient;
 }
 
+void PitchTrackerView::setupActions(int initialTuning, int initialMethod)
+{
+    // Add pitch-tracker-specific view menus
+    QMenu *viewMenu = findMenu("View");
+        
+    QMenu *tuningsMenu = new QMenu(tr("Tunings"), viewMenu);
+    m_tuningsActionGroup = new QActionGroup(this);
+    
+    {
+        QVectorIterator<Accidentals::Tuning*> it(m_availableTunings);    
+        while (it.hasNext()) {
+            QAction *tuning =
+              new QAction(QString::fromStdString(it.next()->getName()),
+                          m_tuningsActionGroup);
+            tuning->setCheckable(true);
+            tuningsMenu->addAction(tuning);
+        }
+        m_tuningsActionGroup->actions().at(initialTuning)->setChecked(true);
+    }
+    
+    connect(m_tuningsActionGroup, SIGNAL(triggered(QAction *)),
+            this, SLOT(slotNewTuningFromAction(QAction *)));
+ 
+    
+    QMenu *methodsMenu = new QMenu(tr("Pitch estimate method"), viewMenu);
+    m_methodsActionGroup = new QActionGroup(this);
+    
+    {
+        QVectorIterator<PitchDetector::Method> it(*PitchDetector::getMethods());
+        while (it.hasNext()) {
+            QAction *method = new QAction(it.next(), m_methodsActionGroup);
+            method->setCheckable(true);
+            methodsMenu->addAction(method);
+        }
+        m_methodsActionGroup->actions().at(initialMethod)->setChecked(true);
+    }
+    
+    connect(m_methodsActionGroup, SIGNAL(triggered(QAction *)),
+            this, SLOT(slotNewPitchEstimationMethod(QAction *)));
+    
+    viewMenu->addSeparator();
+    viewMenu->addMenu(tuningsMenu);
+    viewMenu->addMenu(methodsMenu);
+}
+
+void
+PitchTrackerView::slotNewTuningFromAction(QAction *a)
+{
+    const int whichTuning = m_tuningsActionGroup->actions().indexOf(a);
+    m_tuning = m_availableTunings[whichTuning];
+    m_pitchGraphWidget->setTuning(m_tuning);
+    m_pitchGraphWidget->repaint();
+}
+
+void
+PitchTrackerView::slotNewPitchEstimationMethod(QAction *a)
+{
+    const int whichMethod = m_methodsActionGroup->actions().indexOf(a);
+    qDebug() << "Method " << whichMethod << " name: " << PitchDetector::getMethods()->at(whichMethod);
+    m_pitchDetector->setMethod(PitchDetector::getMethods()->at(whichMethod));
+    m_pitchGraphWidget->repaint();
+}
+
+
 void
 PitchTrackerView::setSegments(RosegardenDocument *document,
                               std::vector<Segment *> /* segments */)
 {
     // m_document is owned by our parent, NotationView
     if (m_document) {
-        disconnect(m_document, SIGNAL(pointerPositionChanged(timeT)),
-                   this, SLOT(slotPointerPositionChanged(timeT)));
+        //disconnect(m_document, SIGNAL(pointerPositionChanged(timeT)),
+        //           this, SLOT(slotPointerPositionChanged(timeT)));
     }
     m_document = document;
 
