@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -194,8 +194,8 @@ TrackButtons::updateUI(Track *track)
             label->setTrackName(tr("<untitled>"));
         }
     } else {
-        label->setTrackName(track->getLabel().c_str());
-        label->setShortName(track->getShortLabel().c_str());
+        label->setTrackName(strtoqstr(track->getLabel()));
+        label->setShortName(strtoqstr(track->getShortLabel()));
     }
 
     initInstrumentNames(ins, label);
