@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -66,7 +66,8 @@ int AudioPreviewPainter::tileWidth()
 
 void AudioPreviewPainter::paintPreviewImage()
 {
-    const std::vector<float>& values = m_apData->getValues();
+    const CompositionModelImpl::AudioPreviewData::Values &values =
+            m_apData->values;
 
     if (values.empty())
         return;
@@ -86,8 +87,10 @@ void AudioPreviewPainter::paintPreviewImage()
         }
     }
 
-    bool showMinima = m_apData->showsMinima();
-    unsigned int channels = m_apData->getChannels();
+    // This was always false.
+    bool showMinima = false;  //m_apData->showsMinima();
+
+    unsigned int channels = m_apData->channels;
     if (channels == 0) {
         RG_DEBUG << "AudioPreviewPainter::paintPreviewImage : problem with audio file for segment "
                  << m_segment->getLabel().c_str() << endl;
@@ -287,8 +290,8 @@ void AudioPreviewPainter::initializeNewSlice()
     // transparent background
     m_image.setColor(0, qRgba(255, 255, 255, 0));
 
-    // foreground from computeSegmentPreviewColor
-    QColor c = m_model.computeSegmentPreviewColor(m_segment);
+    // foreground from getPreviewColour()
+    QColor c = m_segment->getPreviewColour();
     QRgb rgba = qRgba(c.red(), c.green(), c.blue(), 255);
     m_image.setColor(1, rgba);
 
