@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,35 +16,32 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_COMPOSITIONITEMHELPER_H_
-#define _RG_COMPOSITIONITEMHELPER_H_
+#ifndef RG_COMPOSITIONITEMHELPER_H
+#define RG_COMPOSITIONITEMHELPER_H
 
 #include "CompositionModelImpl.h"
 #include "base/Event.h"
 
-
-
-
 namespace Rosegarden
 {
 
+
 class SnapGrid;
 class Segment;
 
-
 class CompositionItemHelper {
 public:
-    static timeT getStartTime(const CompositionItem&, const SnapGrid&);
-    static timeT getEndTime(const CompositionItem&, const SnapGrid&);
-    static int getTrackPos(const CompositionItem&, const SnapGrid&);
-    static void setStartTime(CompositionItem&, timeT, const SnapGrid&);
-    static void setEndTime(CompositionItem&, timeT, const SnapGrid&);
-    static Segment* getSegment(CompositionItem);
-    static CompositionItem makeCompositionItem(Segment*);
+    static timeT getStartTime(CompositionItemPtr, const SnapGrid&);
+    static timeT getEndTime(CompositionItemPtr, const SnapGrid&);
+    static int getTrackPos(CompositionItemPtr, const SnapGrid&);
+    static void setStartTime(CompositionItemPtr, timeT, const SnapGrid&);
+    static void setEndTime(CompositionItemPtr, timeT, const SnapGrid&);
+    static Segment* getSegment(CompositionItemPtr);
+    static CompositionItemPtr makeCompositionItem(Segment*);
     /**
-     * return the CompositionItem in the model which references the same segment as referenceItem
+     * return the CompositionItemPtr in the model which references the same segment as referenceItem
      */
-    static CompositionItem findSiblingCompositionItem(const CompositionModelImpl::itemcontainer& items, const CompositionItem& referenceItem);
+    static CompositionItemPtr findSiblingCompositionItem(const CompositionModelImpl::ItemContainer& items, CompositionItemPtr referenceItem);
 
 };
 
