@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -18,30 +18,24 @@
 #ifndef RG_COMPOSITIONMODELIMPL_H
 #define RG_COMPOSITIONMODELIMPL_H
 
-#include "base/Selection.h"
 #include "base/SnapGrid.h"
 #include "CompositionRect.h"
 #include "CompositionItem.h"
 #include "SegmentOrderer.h"
-#include "base/Event.h"
-
-#include <map>
-#include <set>
 
 #include <QColor>
 #include <QPoint>
-
 #include <QRect>
-#include <vector>
 
-class RectRanges;
-class AudioPreviewDrawData;
-class AudioPreviewData;
+#include <vector>
+#include <map>
+#include <set>
 
 
 namespace Rosegarden
 {
 
+
 class Studio;
 class Segment;
 class RulerScale;
@@ -50,30 +44,46 @@ class Composition;
 class AudioPreviewUpdater;
 class AudioPreviewThread;
 
+/// For Audio Previews
 typedef std::vector<QImage> PixmapArray;
 
-/// Composition User Interface Controller.
+/// Segment previews and selection functionality.
 /**
- * In the Entity/Boundary/Control model, this is (roughly) a control class.
- * Composition is the associated entity (problem domain object) class, while
- * CompositionView is the associated boundary (interface) class.
+ * I assume that by Model we are referring to Smalltalk's
+ * Model/View/Controller pattern.  Qt has a modified Model/View version
+ * of this.  Maybe this is in some way related?  MVC never made any
+ * sense to me.  Smalltalk doesn't make any sense to me.
  *
- * This class might be renamed CompositionUIController.
+ * A skim of this indicates that it is mostly random functionality (e.g.
+ * selection and previews) that is closely tied to CompositionView.  This
+ * could probably be combined with CompositionView into one gigantic
+ * monster-class, then big coherent pieces (like selection and previews)
+ * broken off into smaller, more sensible classes.
+ *
+ * This class works together with CompositionView to provide the composition
+ * user interface (the segment canvas).  TrackEditor creates and owns the
+ * only instance of this class.
  */
 class CompositionModelImpl : public QObject, public CompositionObserver, public SegmentObserver
 {
     Q_OBJECT
 public:
+    CompositionModelImpl(Composition& compo,
+                         Studio& studio,
+                         RulerScale *rulerScale,
+                         int vStep);
 
-    struct CompositionItemCompare {
-        bool operator()(const CompositionItem &c1, const CompositionItem &c2) const;
+    virtual ~CompositionModelImpl();
+
+    typedef std::vector<QRect> RectList;
+
+    struct RectRange {
+        std::pair<RectList::iterator, RectList::iterator> range;
+        QPoint basePoint;
+        QColor color;
     };
 
-    typedef std::vector<QRect> rectlist;
-    // ??? rename: ycoordlist  This is not a height list.
-    typedef std::vector<int> heightlist;
-    typedef std::vector<CompositionRect> rectcontainer;
-    typedef std::set<CompositionItem, CompositionItemCompare> itemcontainer;
+    typedef std::vector<RectRange> RectRanges;
 
     struct AudioPreviewDrawDataItem {
         AudioPreviewDrawDataItem(PixmapArray p, QPoint bp, QRect r) :
@@ -90,109 +100,180 @@ public:
 
     typedef std::vector<AudioPreviewDrawDataItem> AudioPreviewDrawData;
 
-    struct RectRange {
-        std::pair<rectlist::iterator, rectlist::iterator> range;
-        QPoint basePoint;
-        QColor color;
+    typedef std::vector<CompositionRect> RectContainer;
+
+    /// Get the segment rectangles and segment previews
+    const RectContainer& getSegmentRects(const QRect &clipRect,
+                                         RectRanges *notationPreview,
+                                         AudioPreviewDrawData *audioPreview);
+
+    typedef std::vector<int> YCoordList;
+
+    /// Get the Y coords of each track within clipRect.
+    /**
+     * CompositionView::drawSegments() uses this to draw the track dividers.
+     */
+    YCoordList getTrackDividersIn(const QRect &clipRect);
+
+    /// Compares Segment pointers in a CompositionItem.
+    /**
+     * Is this really better than just comparing the CompositionItemPtr
+     * addresses?
+     *
+     *    // Compare the QPointer addresses
+     *    return c1.data() < c2.data();
+     *
+     * All this indexing with pointers gives me the willies.  IDs are safer.
+     */
+    struct CompositionItemCompare {
+        bool operator()(CompositionItemPtr c1, CompositionItemPtr c2) const
+        {
+            // This strikes me as odd.  I think the one below is better.
+            //return CompositionItemHelper::getSegment(c1) < CompositionItemHelper::getSegment(c2);
+
+            // operator< on Segment *'s?  I guess order isn't too important.
+            return c1->getSegment() < c2->getSegment();
+        }
     };
 
-    typedef std::vector<RectRange> RectRanges;
+    typedef std::set<CompositionItemPtr, CompositionItemCompare> ItemContainer;
 
-    /// rename: AudioPreview
-    class AudioPreviewData {
-    public:
-        AudioPreviewData(bool showMinima, unsigned int channels) : m_showMinima(showMinima), m_channels(channels) {};
-        // ~AudioPreviewData();
+    /// Used by CompositionView on mouse double-click.
+    ItemContainer getItemsAt(const QPoint &);
+    /// Get the start time of the repeat nearest the point.
+    /**
+     * Used by CompositionView to determine the time at which to edit a repeat.
+     *
+     * Looking closely at the implementation of this, we find that this is a
+     * function that brings together CompositionItem and SnapGrid.  It mainly
+     * uses CompositionItem, so it likely belongs there.  Perhaps more as a
+     *
+     *   CompositionItem::getRepeatTimeAt(const SnapGrid &, const QPoint &)
+     */
+    timeT getRepeatTimeAt(const QPoint &, CompositionItemPtr);
 
-        bool showsMinima()              { return m_showMinima; }
-        void setShowMinima(bool s)      { m_showMinima = s;    }
+    /// Used in many places for various coordinate/time purposes.
+    SnapGrid& grid()  { return m_grid; }
 
-        unsigned int getChannels()       { return m_channels;   }
-        void setChannels(unsigned int c) { m_channels = c;      }
+    // *** Selection
 
-        const std::vector<float> &getValues() const { return m_values;  }
-        void setValues(const std::vector<float>&v) { m_values = v; }
+    void setSelected(CompositionItemPtr, bool selected = true);
+    void setSelected(Segment *, bool selected = true);
+    //void setSelected(const ItemContainer&);
+    void clearSelected();
+    bool isSelected(CompositionItemPtr) const;
+    bool isSelected(const Segment *) const;
+    bool haveSelection() const  { return !m_selectedSegments.empty(); }
+    bool haveMultipleSelection() const  { return m_selectedSegments.size() > 1; }
+    SegmentSelection getSelectedSegments()  { return m_selectedSegments; }
+    /// Bounding rect of the currently selected segments.
+    QRect getSelectionContentsRect();
 
-        QRect getSegmentRect()              { return m_segmentRect; }
-        void setSegmentRect(const QRect& r) { m_segmentRect = r; }
+    /// Emit selectedSegments() signal
+    /**
+     * Used by SegmentSelector and others to signal a change in the selection.
+     */
+    void signalSelection();
 
-    protected:
-        std::vector<float> m_values;
-        bool               m_showMinima;
-        unsigned int       m_channels;
-        QRect              m_segmentRect;
+    /// Click and drag selection rect.
+    void setSelectionRect(const QRect &);
+    /// Click and drag selection complete.
+    void finalizeSelectionRect();
 
-    private:
-        // no copy ctor
-        AudioPreviewData(const AudioPreviewData&);
-    };
+    /// Emit needContentUpdate() signal
+    /**
+     * rename: emitRefreshView()
+     */
+    void signalContentChange();
+
+    // *** Recording
+
+    /// Refresh the recording segments.
+    void pointerPosChanged(int x);
+
+    void addRecordingItem(CompositionItemPtr);
+    //void removeRecordingItem(CompositionItemPtr);
+    void clearRecordingItems();
+    //bool haveRecordingItems()  { return !m_recordingSegments.empty(); }
+
+    // *** Changing (moving and resizing)
 
     enum ChangeType { ChangeMove, ChangeResizeFromStart, ChangeResizeFromEnd };
 
-    CompositionModelImpl(Composition& compo,
-                         Studio& studio,
-                         RulerScale *rulerScale,
-                         int vStep);
-
-    virtual ~CompositionModelImpl();
-
-    unsigned int getNbRows();
-    /// Get the segment rectangles and segment previews
-    const rectcontainer& getSegmentRects(const QRect& clipRect,
-                                         RectRanges* notationPreview, AudioPreviewDrawData* audioPreview);
-    heightlist getTrackDividersIn(const QRect& rect);
-    itemcontainer getItemsAt (const QPoint&);
-    timeT getRepeatTimeAt (const QPoint&, const CompositionItem&);
-
-    SnapGrid& grid() { return m_grid; }
-
-    void setPointerPos(int xPos);
-    void setSelected(const CompositionItem&, bool selected = true);
-    bool isSelected(const CompositionItem&) const;
-    void setSelected(const itemcontainer&);
-    void setSelected(const Segment*, bool selected = true);
-    bool isSelected(const Segment*) const;
-    void clearSelected();
-    bool haveSelection() const { return !m_selectedSegments.empty(); }
-    bool haveMultipleSelection() const { return m_selectedSegments.size() > 1; }
-    void signalSelection();
-    void setSelectionRect(const QRect&);
-    void finalizeSelectionRect();
-    QRect getSelectionContentsRect();
-    void signalContentChange();
-
-    void addRecordingItem(const CompositionItem&);
-    void removeRecordingItem(const CompositionItem &);
-    void clearRecordingItems();
-    bool haveRecordingItems() { return !m_recordingSegments.empty(); }
-
-    void startChange(const CompositionItem&, ChangeType change);
+    /// Begin move/resize for a single segment.
+    void startChange(CompositionItemPtr, ChangeType change);
+    /// Begin move for all selected segments.
     void startChangeSelection(ChangeType change);
-    itemcontainer& getChangingItems() { return m_changingItems; }
+    //ChangeType getChangeType() const  { return m_changeType; }
+    /// Get the segments that are moving or resizing.
+    ItemContainer &getChangingItems()  { return m_changingItems; }
+    /// Cleanup after move/resize.
     void endChange();
-    ChangeType getChangeType() { return m_changeType; }
 
-    void setLength(int width);
-    int  getLength();
+    // *** Misc
 
-    unsigned int getHeight();
+    /// In pixels
+    /**
+     * Used to expand the composition when we go past the end.
+     */
+    void setCompositionLength(int width);
+    /// In pixels
+    /**
+     * Used to expand the composition when we go past the end.
+     */
+    int getCompositionLength();
+    /// Number of pixels needed vertically to render all tracks.
+    unsigned int getCompositionHeight();
     
+    /**
+     * Used by CompositionView's ctor to connect
+     * RosegardenDocument::m_audioPreviewThread.
+     */
     void setAudioPreviewThread(AudioPreviewThread *thread);
-    AudioPreviewThread* getAudioPreviewThread() { return m_audioPreviewThread; }
+    //AudioPreviewThread* getAudioPreviewThread() { return m_audioPreviewThread; }
 
-    void clearPreviewCache();
-    void clearSegmentRectsCache(bool clearPreviews = false) { clearInCache(0, clearPreviews); }
+    /// See CompositionView::clearSegmentRectsCache()
+    void clearSegmentRectsCache(bool clearPreviews = false)
+            { clearInCache(0, clearPreviews); }
 
-    CompositionRect computeSegmentRect(const Segment&, bool computeZ = false);
-    QColor          computeSegmentPreviewColor(const Segment*);
-    QPoint          computeSegmentOrigin(const Segment&);
-    void            computeRepeatMarks(CompositionItem&);
+    CompositionRect computeSegmentRect(const Segment &, bool computeZ = false);
 
-    SegmentSelection getSelectedSegments() { return m_selectedSegments; }
-    Composition&     getComposition()      { return m_composition; }
-    Studio&          getStudio()           { return m_studio; }
+    //void computeRepeatMarks(CompositionItemPtr);
 
+    Composition &getComposition()  { return m_composition; }
+    Studio &getStudio()  { return m_studio; }
 
+    /**
+     * rename: AudioPreview
+     */
+    struct AudioPreviewData {
+        AudioPreviewData() :
+            channels(0)
+        { }
+
+        unsigned int channels;
+
+        typedef std::vector<float> Values;
+        Values values;
+    };
+
+signals:
+    /// rename: refreshView
+    void needContentUpdate();
+    /// rename: refreshView
+    void needContentUpdate(const QRect&);
+    void needArtifactsUpdate();
+    void selectedSegments(const SegmentSelection &);
+    void needSizeUpdate();
+
+public slots:
+    void slotAudioFileFinalized(Segment*);
+    void slotInstrumentParametersChanged(InstrumentId);
+
+private slots:
+    void slotAudioPreviewComplete(AudioPreviewUpdater*);
+
+private:
     // CompositionObserver Interface
     virtual void segmentAdded(const Composition *, Segment *);
     virtual void segmentRemoved(const Composition *, Segment *);
@@ -210,21 +291,8 @@ public:
     virtual void endMarkerTimeChanged(const Segment *, bool /*shorten*/);
     virtual void segmentDeleted(const Segment*) { /* nothing to do - handled by CompositionObserver::segmentRemoved() */ };
 
-signals:
-    void needContentUpdate();
-    void needContentUpdate(const QRect&);
-    void needArtifactsUpdate();
-    void selectedSegments(const SegmentSelection &);
-    void needSizeUpdate();
+    QPoint computeSegmentOrigin(const Segment &);
 
-public slots:
-    void slotAudioFileFinalized(Segment*);
-    void slotInstrumentParametersChanged(InstrumentId);
-
-protected slots:
-    void slotAudioPreviewComplete(AudioPreviewUpdater*);
-
-protected:
     bool setTrackHeights(Segment *changed = 0); // true if something changed
 
     bool isTmpSelected(const Segment*) const;
@@ -250,11 +318,11 @@ protected:
             QPoint basePoint, const Segment* segment,
             const QRect& currentSR, RectRanges* npData);
     /// rename: getNotationPreview()
-    rectlist* getNotationPreviewData(const Segment* s);
+    RectList* getNotationPreviewData(const Segment* s);
     /// rename: cacheNotationPreview()
-    rectlist* makeNotationPreviewDataCache(const Segment *s);
+    RectList* makeNotationPreviewDataCache(const Segment *s);
     /// For notation preview
-    void createEventRects(const Segment* segment, rectlist*);
+    void createEventRects(const Segment* segment, RectList*);
 
     // Audio Previews
     void makeAudioPreviewRects(AudioPreviewDrawData* apRects, const Segment*,
@@ -265,7 +333,10 @@ protected:
     /// rename: cacheAudioPreview()
     AudioPreviewData* makeAudioPreviewDataCache(const Segment *s);
     /// rename: makeAudioPreview()
-    void updatePreviewCacheForAudioSegment(const Segment* s, AudioPreviewData* apData);
+    void updatePreviewCacheForAudioSegment(const Segment* s);
+
+    /// Clear notation and audio preview caches.
+    void clearPreviewCache();
 
     // Segment Rects (m_segmentRectMap)
     void putInCache(const Segment*, const CompositionRect&);
@@ -278,32 +349,33 @@ protected:
     Composition&     m_composition;
     Studio&          m_studio;
     SnapGrid         m_grid;
+
     SegmentSelection m_selectedSegments;
     SegmentSelection m_tmpSelectedSegments;
     SegmentSelection m_previousTmpSelectedSegments;
 
     timeT            m_pointerTimePos;
 
-    typedef std::set<Segment *> recordingsegmentset;
-    recordingsegmentset          m_recordingSegments;
+    typedef std::set<Segment *>  RecordingSegmentSet;
+    RecordingSegmentSet          m_recordingSegments;
 
     AudioPreviewThread*          m_audioPreviewThread;
 
     // Notation Preview
-    typedef std::map<const Segment *, rectlist *> NotationPreviewDataCache;
+    typedef std::map<const Segment *, RectList *> NotationPreviewDataCache;
     NotationPreviewDataCache     m_notationPreviewDataCache;
 
     // Audio Preview
     typedef std::map<const Segment *, AudioPreviewData *> AudioPreviewDataCache;
     AudioPreviewDataCache        m_audioPreviewDataCache;
 
-    /// Member object which allows us to return a reference for speed.
-    rectcontainer m_segmentRects;
-    itemcontainer m_changingItems;
-    ChangeType    m_changeType;
+    /// Used by getSegmentRects() to return a reference for speed.
+    RectContainer m_segmentRects;
 
-    typedef std::vector<CompositionItem> itemgc;
-    itemgc m_itemGC;
+    ChangeType    m_changeType;
+    ItemContainer m_changingItems;
+    typedef std::vector<CompositionItemPtr> ItemGC;
+    ItemGC m_itemGC;
 
     QRect m_selectionRect;
     QRect m_previousSelectionUpdateRect;
@@ -319,8 +391,6 @@ protected:
 
     SegmentOrderer m_segmentOrderer;
 
-    CompositionItem* m_currentCompositionItem;
-
 };
 
 
