@@ -3,7 +3,7 @@
 /*
   Rosegarden
   A MIDI and audio sequencer and musical notation editor.
-  Copyright 2000-2013 the Rosegarden development team.
+  Copyright 2000-2014 the Rosegarden development team.
  
   Other copyrights also apply to some parts of this work.  Please
   see the AUTHORS file and individual file headers for details.
@@ -27,7 +27,7 @@
 #include "base/Profiler.h"
 #include "CompositionColourCache.h"
 #include "CompositionItemHelper.h"
-#include "CompositionItemImpl.h"
+#include "CompositionItem.h"
 #include "CompositionRect.h"
 #include "AudioPreviewPainter.h"
 #include "document/RosegardenDocument.h"
@@ -62,20 +62,6 @@
 namespace Rosegarden
 {
 
-class PreviewRect : public QRect {
-public:
-    PreviewRect(int left, int top, int width, int height) :
-        QRect(left, top, width, height) {};
-
-    PreviewRect(const QRect& r) :
-        QRect(r) {};
-
-    const QColor& getColor() const { return m_color; }
-    void setColor(QColor c) { m_color = c; }
-
-protected:
-    QColor m_color;
-};
 
 CompositionView::CompositionView(RosegardenDocument* doc,
                                  CompositionModelImpl* model,
@@ -90,7 +76,7 @@ CompositionView::CompositionView(RosegardenDocument* doc,
     m_showSegmentLabels(true),
     m_fineGrain(false),
     m_pencilOverExisting(false),
-    m_minWidth(m_model->getLength()),
+    //m_minWidth(m_model->getCompositionLength()),
     m_stepSize(0),
     m_rectFill(0xF0, 0xF0, 0xF0),
     m_selectedRectFill(0x00, 0x00, 0xF0),
@@ -180,9 +166,8 @@ CompositionView::CompositionView(RosegardenDocument* doc,
                 getModel(), SLOT(slotAudioFileFinalized(Segment*)));
     }
     
-    CompositionModelImpl* cmi = dynamic_cast<CompositionModelImpl*>(model);
-    if (cmi) {
-        cmi->setAudioPreviewThread(&doc->getAudioPreviewThread());
+    if (model) {
+        model->setAudioPreviewThread(&doc->getAudioPreviewThread());
     }
 
     if (doc) {
@@ -206,9 +191,8 @@ CompositionView::CompositionView(RosegardenDocument* doc,
 
 void CompositionView::endAudioPreviewGeneration()
 {
-    CompositionModelImpl* cmi = dynamic_cast<CompositionModelImpl*>(m_model);
-    if (cmi) {
-        cmi->setAudioPreviewThread(0);
+    if (m_model) {
+        m_model->setAudioPreviewThread(0);
     }
 }
 
@@ -230,8 +214,8 @@ void CompositionView::initStepSize()
 void CompositionView::slotUpdateSize()
 {
 //    int vStep = getModel()->grid().getYSnap();
-//    int height = std::max(getModel()->getNbRows() * vStep, (unsigned)visibleHeight());
-    int height = std::max(getModel()->getHeight(), (unsigned) visibleHeight());
+//    int height = std::max(getModel()->m_composition.getNbTracks() * vStep, (unsigned)visibleHeight());
+    int height = std::max(getModel()->getCompositionHeight(), (unsigned) visibleHeight());
 
     const RulerScale *ruler = grid().getRulerScale();
 
@@ -307,13 +291,13 @@ void CompositionView::setDrawSelectionRect(bool d)
 
 void CompositionView::clearSegmentRectsCache(bool clearPreviews)
 {
-    dynamic_cast<CompositionModelImpl*>(getModel())->clearSegmentRectsCache(clearPreviews);
+    getModel()->clearSegmentRectsCache(clearPreviews);
 }
 
 SegmentSelection
 CompositionView::getSelectedSegments()
 {
-    return (dynamic_cast<CompositionModelImpl*>(m_model))->getSelectedSegments();
+    return m_model->getSelectedSegments();
 }
 
 void CompositionView::updateSelectionContents()
@@ -362,7 +346,7 @@ void CompositionView::selectSegments(const SegmentSelection &segments)
     getModel()->clearSelected();
 
     for (SegmentSelection::iterator i = segments.begin(); i != segments.end(); ++i) {
-        getModel()->setSelected(CompositionItem(new CompositionItemImpl(**i, dummy)));
+        getModel()->setSelected(CompositionItemPtr(new CompositionItem(**i, dummy)));
     }
     slotUpdateAll();
 }
@@ -421,21 +405,21 @@ void CompositionView::slotExternalWheelEvent(QWheelEvent* e)
     wheelEvent(e);
 }
 
-CompositionItem CompositionView::getFirstItemAt(QPoint pos)
+CompositionItemPtr CompositionView::getFirstItemAt(QPoint pos)
 {
-    CompositionModelImpl::itemcontainer items = getModel()->getItemsAt(pos);
+    CompositionModelImpl::ItemContainer items = getModel()->getItemsAt(pos);
 
     if (items.size()) {
         // find topmost item
-        CompositionItem res = *(items.begin());
+        CompositionItemPtr res = *(items.begin());
 
         unsigned int maxZ = res->z();
 
-        CompositionModelImpl::itemcontainer::iterator maxZItemPos = items.begin();
+        CompositionModelImpl::ItemContainer::iterator maxZItemPos = items.begin();
 
-        for (CompositionModelImpl::itemcontainer::iterator i = items.begin();
+        for (CompositionModelImpl::ItemContainer::iterator i = items.begin();
              i != items.end(); ++i) {
-            CompositionItem ic = *i;
+            CompositionItemPtr ic = *i;
             if (ic->z() > maxZ) {
                 res = ic;
                 maxZ = ic->z();
@@ -445,7 +429,7 @@ CompositionItem CompositionView::getFirstItemAt(QPoint pos)
 
         // get rid of the rest;
         items.erase(maxZItemPos);
-        for (CompositionModelImpl::itemcontainer::iterator i = items.begin();
+        for (CompositionModelImpl::ItemContainer::iterator i = items.begin();
              i != items.end(); ++i)
             delete *i;
 
@@ -453,7 +437,7 @@ CompositionItem CompositionView::getFirstItemAt(QPoint pos)
     }
 
 
-    return CompositionItem();
+    return CompositionItemPtr();
 }
 
 void CompositionView::setSnapGrain(bool fine)
@@ -861,7 +845,7 @@ void CompositionView::refreshArtifacts(const QRect& rect)
     //    m_artifactsNeedRefresh = false;
 }
 
-void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& clipRect)
+void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect &clipRect)
 {
     Profiler profiler("CompositionView::drawSegments");
 
@@ -875,7 +859,7 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
     // though the center of the divider might be slightly outside of the
     // viewport.
     // This is not a height list.
-    CompositionModelImpl::heightlist trackYCoords =
+    CompositionModelImpl::YCoordList trackYCoords =
             getModel()->getTrackDividersIn(clipRect.adjusted(0,-1,0,+1));
 
     if (!trackYCoords.empty()) {
@@ -890,7 +874,7 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
 
         // For each track Y coordinate, draw the two light lines in the middle
         // of the track divider.
-        for (CompositionModelImpl::heightlist::const_iterator yi = trackYCoords.begin();
+        for (CompositionModelImpl::YCoordList::const_iterator yi = trackYCoords.begin();
              yi != trackYCoords.end(); ++yi) {
             // Upper line.
             int y = *yi - 1;
@@ -914,7 +898,7 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
 
         // For each track Y coordinate, draw the two dark lines on the outside
         // of the track divider.
-        for (CompositionModelImpl::heightlist::const_iterator yi = trackYCoords.begin();
+        for (CompositionModelImpl::YCoordList::const_iterator yi = trackYCoords.begin();
              yi != trackYCoords.end(); ++yi) {
             // Upper line
             int y = *yi - 2;
@@ -938,27 +922,26 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
     // *** Get Segment and Preview Rectangles
 
     // Assume we aren't going to show previews.
-    CompositionModelImpl::AudioPreviewDrawData* audioPreviewData = 0;
-    CompositionModelImpl::RectRanges* notationPreviewData = 0;
+    CompositionModelImpl::RectRanges *notationPreview = 0;
+    CompositionModelImpl::AudioPreviewDrawData *audioPreview = 0;
 
     if (m_showPreviews) {
-        // Clear the rect containers.  Apparently getRectanglesIn() will not.
+        // Clear the previews.  Apparently getSegmentRects() will not.
         // Given that this is the only caller, this should be moved into
-        // getRectanglesIn().
-        m_notationPreviewRects.clear();
-        m_audioPreviewRects.clear();
+        // getSegmentRects().
+        m_notationPreview.clear();
+        m_audioPreview.clear();
 
-        // Indicate that we want preview rects.
-        notationPreviewData = &m_notationPreviewRects;
-        audioPreviewData = &m_audioPreviewRects;
+        // Indicate that we want previews.
+        notationPreview = &m_notationPreview;
+        audioPreview = &m_audioPreview;
     }
 
-    // Fetch segment rectangles and (optionally) preview rectangles
-    const CompositionModelImpl::rectcontainer& rects =
-        getModel()->getSegmentRects(clipRect,
-                                    notationPreviewData, audioPreviewData);
+    // Fetch segment rectangles and (optionally) previews
+    const CompositionModelImpl::RectContainer &segmentRects =
+        getModel()->getSegmentRects(clipRect, notationPreview, audioPreview);
 
-    CompositionModelImpl::rectcontainer::const_iterator end = rects.end();
+    CompositionModelImpl::RectContainer::const_iterator end = segmentRects.end();
 
     // *** Draw Segment Rectangles
 
@@ -968,7 +951,7 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
         segmentLayerPainter->save();
 
         // For each segment rectangle, draw it
-        for (CompositionModelImpl::rectcontainer::const_iterator i = rects.begin();
+        for (CompositionModelImpl::RectContainer::const_iterator i = segmentRects.begin();
              i != end; ++i) {
             segmentLayerPainter->setBrush(i->getBrush());
             segmentLayerPainter->setPen(i->getPen());
@@ -983,9 +966,9 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
     {
         Profiler profiler("CompositionView::drawSegments(): intersections");
 
-        if (rects.size() > 1) {
+        if (segmentRects.size() > 1) {
             //RG_DEBUG << "CompositionView::drawSegments : drawing intersections\n";
-            drawIntersections(rects, segmentLayerPainter, clipRect);
+            drawIntersections(segmentRects, segmentLayerPainter, clipRect);
         }
     }
 
@@ -994,29 +977,34 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
     if (m_showPreviews) {
         segmentLayerPainter->save();
 
+        // Audio Previews
+
         {
             Profiler profiler("CompositionView::drawSegments: audio previews");
 
-            // draw audio previews
-            //
             drawAudioPreviews(segmentLayerPainter, clipRect);
         }
 
+        // Notation Previews
+
         Profiler profiler("CompositionView::drawSegments: note previews");
 
-        // draw notation previews
-        //
-        CompositionModelImpl::RectRanges::const_iterator npi = m_notationPreviewRects.begin();
-        CompositionModelImpl::RectRanges::const_iterator npEnd = m_notationPreviewRects.end();
+        CompositionModelImpl::RectRanges::const_iterator npi = m_notationPreview.begin();
+        CompositionModelImpl::RectRanges::const_iterator npEnd = m_notationPreview.end();
 
+        // For each preview range
+        // ??? I think there is never more than one range here.  We should be
+        //     able to switch from RectRanges to RectRange.
         for (; npi != npEnd; ++npi) {
             CompositionModelImpl::RectRange interval = *npi;
             segmentLayerPainter->save();
             segmentLayerPainter->translate(
                     interval.basePoint.x(), interval.basePoint.y());
-//            RG_DEBUG << "CompositionView::drawSegments : translating to x = " << interval.basePoint.x() << endl;
+            //RG_DEBUG << "CompositionView::drawSegments : translating to x = " << interval.basePoint.x() << endl;
+
+            // For each event rectangle
             for (; interval.range.first != interval.range.second; ++interval.range.first) {
-                const PreviewRect& pr = *(interval.range.first);
+                const QRect &pr = *(interval.range.first);
                 QColor defaultCol = CompositionColourCache::getInstance()->SegmentInternalPreview;
                 QColor col = interval.color.isValid() ? interval.color : defaultCol;
                 segmentLayerPainter->setBrush(col);
@@ -1037,7 +1025,7 @@ void CompositionView::drawSegments(QPainter *segmentLayerPainter, const QRect& c
     //
     if (m_showSegmentLabels) {
         Profiler profiler("CompositionView::drawSegments: labels");
-        for (CompositionModelImpl::rectcontainer::const_iterator i = rects.begin();
+        for (CompositionModelImpl::RectContainer::const_iterator i = segmentRects.begin();
              i != end; ++i) {
             drawCompRectLabel(*i, segmentLayerPainter, clipRect);
         }
@@ -1051,8 +1039,8 @@ void CompositionView::drawAudioPreviews(QPainter * p, const QRect& clipRect)
 {
     Profiler profiler("CompositionView::drawAudioPreviews");
 
-    CompositionModelImpl::AudioPreviewDrawData::const_iterator api = m_audioPreviewRects.begin();
-    CompositionModelImpl::AudioPreviewDrawData::const_iterator apEnd = m_audioPreviewRects.end();
+    CompositionModelImpl::AudioPreviewDrawData::const_iterator api = m_audioPreview.begin();
+    CompositionModelImpl::AudioPreviewDrawData::const_iterator apEnd = m_audioPreview.end();
     QRect rectToFill,  // rect to fill on canvas
         localRect; // the rect of the tile to draw on the canvas
     QPoint basePoint,  // origin of segment rect
@@ -1410,15 +1398,15 @@ QColor CompositionView::mixBrushes(QBrush a, QBrush b)
     return ac;
 }
 
-void CompositionView::drawIntersections(const CompositionModelImpl::rectcontainer& rects,
+void CompositionView::drawIntersections(const CompositionModelImpl::RectContainer& rects,
                                         QPainter * p, const QRect& clipRect)
 {
     if (! (rects.size() > 1))
         return ;
 
-    CompositionModelImpl::rectcontainer intersections;
+    CompositionModelImpl::RectContainer intersections;
 
-    CompositionModelImpl::rectcontainer::const_iterator i = rects.begin(),
+    CompositionModelImpl::RectContainer::const_iterator i = rects.begin(),
         j = rects.begin();
 
     for (; j != rects.end(); ++j) {
@@ -1433,7 +1421,7 @@ void CompositionView::drawIntersections(const CompositionModelImpl::rectcontaine
         for (; i != rects.end(); ++i) {
             CompositionRect ri = testRect.intersect(*i);
             if (!ri.isEmpty()) {
-                CompositionModelImpl::rectcontainer::iterator t = std::find(intersections.begin(),
+                CompositionModelImpl::RectContainer::iterator t = std::find(intersections.begin(),
                                                                         intersections.end(), ri);
                 if (t == intersections.end()) {
                     ri.setBrush(mixBrushes(testRect.getBrush(), i->getBrush()));
@@ -1452,7 +1440,7 @@ void CompositionView::drawIntersections(const CompositionModelImpl::rectcontaine
 
     while (!intersections.empty()) {
 
-        for (CompositionModelImpl::rectcontainer::iterator intIter = intersections.begin();
+        for (CompositionModelImpl::RectContainer::iterator intIter = intersections.begin();
              intIter != intersections.end(); ++intIter) {
             CompositionRect r = *intIter;
             drawCompRect(r, p, clipRect, intersectionLvl);
@@ -1463,9 +1451,9 @@ void CompositionView::drawIntersections(const CompositionModelImpl::rectcontaine
 
         ++intersectionLvl;
 
-        CompositionModelImpl::rectcontainer intersections2;
+        CompositionModelImpl::RectContainer intersections2;
 
-        CompositionModelImpl::rectcontainer::iterator i = intersections.begin(),
+        CompositionModelImpl::RectContainer::iterator i = intersections.begin(),
             j = intersections.begin();
 
         for (; j != intersections.end(); ++j) {
@@ -1480,7 +1468,7 @@ void CompositionView::drawIntersections(const CompositionModelImpl::rectcontaine
             for (; i != intersections.end(); ++i) {
                 CompositionRect ri = testRect.intersect(*i);
                 if (!ri.isEmpty() && ri != *i) {
-                    CompositionModelImpl::rectcontainer::iterator t = std::find(intersections2.begin(),
+                    CompositionModelImpl::RectContainer::iterator t = std::find(intersections2.begin(),
                                                                             intersections2.end(), ri);
                     if (t == intersections2.end())
                         ri.setBrush(mixBrushes(testRect.getBrush(), i->getBrush()));
@@ -1662,7 +1650,7 @@ void CompositionView::contentsMouseDoubleClickEvent(QMouseEvent* e)
 
     RG_DEBUG << "CompositionView::contentsMouseDoubleClickEvent - have currentIndex\n";
 
-    CompositionItemImpl* itemImpl = dynamic_cast<CompositionItemImpl*>((_CompositionItem*)m_currentIndex);
+    CompositionItem* itemImpl = m_currentIndex;
 
     if (m_currentIndex->isRepeating()) {
         timeT time = getModel()->getRepeatTimeAt(e->pos(), m_currentIndex);
@@ -1724,7 +1712,7 @@ void CompositionView::contentsMouseMoveEvent(QMouseEvent* e)
 // Dead Code.
 void CompositionView::releaseCurrentItem()
 {
-    m_currentIndex = CompositionItem();
+    m_currentIndex = CompositionItemPtr();
 }
 #endif
 
@@ -1735,15 +1723,15 @@ void CompositionView::setPointerPos(int pos)
     if (oldPos == pos) return;
 
     m_pointerPos = pos;
-    getModel()->setPointerPos(pos);
+    getModel()->pointerPosChanged(pos);
 
     // automagically grow contents width if pointer position goes beyond right end
     //
     if (pos >= (contentsWidth() - m_stepSize)) {
         resizeContents(pos + m_stepSize, contentsHeight());
         // grow composition too, if needed (it may not be the case if
-        if (getModel()->getLength() < contentsWidth())
-            getModel()->setLength(contentsWidth());
+        if (getModel()->getCompositionLength() < contentsWidth())
+            getModel()->setCompositionLength(contentsWidth());
     }
 
 
