@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -58,6 +58,10 @@ class CompositionRect;
  * and the artifacts (playback position pointer, guides, "rubber band"
  * selection, ...) on the viewport (the portion of the composition that
  * is currently visible).
+ *
+ * TrackEditor creates and owns the only instance of this class.  This
+ * class works together with CompositionModelImpl to provide the composition
+ * user interface (the segment canvas).
  */
 class CompositionView : public RosegardenScrollView 
 {
@@ -118,7 +122,7 @@ public:
     SnapGrid& grid() { return m_model->grid(); }
 
     /// Get the topmost item (segment) at the given position on the view.
-    CompositionItem getFirstItemAt(QPoint pos);
+    CompositionItemPtr getFirstItemAt(QPoint pos);
 
     /// Returns the segment tool box.  See setTool() and m_toolBox.
     SegmentToolBox* getToolBox() { return m_toolBox; }
@@ -474,7 +478,7 @@ protected:
      */
     void drawCompRectLabel(const CompositionRect& r, QPainter *p, const QRect& clipRect);
     /// Used by drawSegments() to draw any intersections between rectangles.
-    void drawIntersections(const CompositionModelImpl::rectcontainer&, QPainter * p, const QRect& clipRect);
+    void drawIntersections(const CompositionModelImpl::RectContainer &, QPainter *p, const QRect &clipRect);
 
     /// Used by drawArtifacts() to draw the playback position pointer.
     /**
@@ -615,7 +619,7 @@ protected:
     //--------------- Data members ---------------------------------
 
     CompositionModelImpl* m_model;
-    CompositionItem m_currentIndex;
+    CompositionItemPtr m_currentIndex;
 
     SegmentTool*    m_tool;
     SegmentToolBox* m_toolBox;
@@ -628,7 +632,7 @@ protected:
     bool         m_fineGrain;
     bool         m_pencilOverExisting;
 
-    int          m_minWidth;
+    //int          m_minWidth;
 
     int          m_stepSize;
     QColor       m_rectFill;
@@ -694,8 +698,8 @@ protected:
     QString      m_toolContextHelp;
     bool         m_contextHelpShown;
 
-    CompositionModelImpl::AudioPreviewDrawData m_audioPreviewRects;
-    CompositionModelImpl::RectRanges m_notationPreviewRects;
+    CompositionModelImpl::AudioPreviewDrawData m_audioPreview;
+    CompositionModelImpl::RectRanges m_notationPreview;
 
     /// Drives slotUpdateTimer().
     QTimer *m_updateTimer;
