@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -56,15 +56,15 @@ SegmentMover::SegmentMover(CompositionView *c, RosegardenDocument *d)
 void SegmentMover::ready()
 {
     m_canvas->viewport()->setCursor(Qt::SizeAllCursor);
-    connect(m_canvas, SIGNAL(contentsMoving (int, int)),
-            this, SLOT(slotCanvasScrolled(int, int)));
+    //connect(m_canvas, SIGNAL(contentsMoving (int, int)),
+    //        this, SLOT(slotCanvasScrolled(int, int)));
     setBasicContextHelp();
 }
 
 void SegmentMover::stow()
 {
-    disconnect(m_canvas, SIGNAL(contentsMoving (int, int)),
-               this, SLOT(slotCanvasScrolled(int, int)));
+    //disconnect(m_canvas, SIGNAL(contentsMoving (int, int)),
+    //           this, SLOT(slotCanvasScrolled(int, int)));
 }
 
 void SegmentMover::slotCanvasScrolled(int newX, int newY)
@@ -80,7 +80,7 @@ void SegmentMover::slotCanvasScrolled(int newX, int newY)
 
 void SegmentMover::handleMouseButtonPress(QMouseEvent *e)
 {
-    CompositionItem item = m_canvas->getFirstItemAt(e->pos());
+    CompositionItemPtr item = m_canvas->getFirstItemAt(e->pos());
     SegmentSelector* selector = dynamic_cast<SegmentSelector*>
                                 (getToolBox()->getTool("segmentselector"));
 
@@ -114,7 +114,7 @@ void SegmentMover::handleMouseButtonPress(QMouseEvent *e)
             m_canvas->getModel()->startChangeSelection(CompositionModelImpl::ChangeMove);
 
 
-            CompositionModelImpl::itemcontainer& changingItems = m_canvas->getModel()->getChangingItems();
+            CompositionModelImpl::ItemContainer& changingItems = m_canvas->getModel()->getChangingItems();
             // set m_currentIndex to its "sibling" among selected (now moving) items
             setCurrentIndex(CompositionItemHelper::findSiblingCompositionItem(changingItems, m_currentIndex));
 
@@ -152,20 +152,20 @@ void SegmentMover::handleMouseButtonRelease(QMouseEvent *e)
 
         if (changeMade()) {
 
-            CompositionModelImpl::itemcontainer& changingItems = m_canvas->getModel()->getChangingItems();
+            CompositionModelImpl::ItemContainer& changingItems = m_canvas->getModel()->getChangingItems();
 
             SegmentReconfigureCommand *command =
                 new SegmentReconfigureCommand
-                (changingItems.size() == 1 ? tr("Move Segment") : tr("Move Segments"));
+                (changingItems.size() == 1 ? tr("Move Segment") : tr("Move Segments"), &comp);
 
 
-            CompositionModelImpl::itemcontainer::iterator it;
+            CompositionModelImpl::ItemContainer::iterator it;
 
             for (it = changingItems.begin();
                     it != changingItems.end();
                     ++it) {
 
-                CompositionItem item = *it;
+                CompositionItemPtr item = *it;
 
                 Segment* segment = CompositionItemHelper::getSegment(item);
 
@@ -208,7 +208,7 @@ void SegmentMover::handleMouseButtonRelease(QMouseEvent *e)
     }
 
     setChangeMade(false);
-    m_currentIndex = CompositionItem();
+    m_currentIndex = CompositionItemPtr();
 
     setBasicContextHelp();
 }
@@ -230,12 +230,12 @@ int SegmentMover::handleMouseMove(QMouseEvent *e)
         clearContextHelp();
     }
 
-    CompositionModelImpl::itemcontainer& changingItems = m_canvas->getModel()->getChangingItems();
+    CompositionModelImpl::ItemContainer& changingItems = m_canvas->getModel()->getChangingItems();
 
     //         RG_DEBUG << "SegmentMover::handleMouseMove : nb changingItems = "
     //                  << changingItems.size() << endl;
 
-    CompositionModelImpl::itemcontainer::iterator it;
+    CompositionModelImpl::ItemContainer::iterator it;
     int guideX = 0;
     int guideY = 0;
     QRect updateRect;
