@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -73,8 +73,8 @@ SegmentSelector::~SegmentSelector()
 void SegmentSelector::ready()
 {
     m_canvas->viewport()->setCursor(Qt::ArrowCursor);
-    connect(m_canvas, SIGNAL(contentsMoving (int, int)),
-            this, SLOT(slotCanvasScrolled(int, int)));
+    //connect(m_canvas, SIGNAL(contentsMoving (int, int)),
+    //        this, SLOT(slotCanvasScrolled(int, int)));
     setContextHelp(tr("Click and drag to select segments"));
 }
 
@@ -95,7 +95,7 @@ SegmentSelector::handleMouseButtonPress(QMouseEvent *e)
     RG_DEBUG << "SegmentSelector::handleMouseButtonPress\n";
     m_buttonPressed = true;
 
-    CompositionItem item = m_canvas->getFirstItemAt(e->pos());
+    CompositionItemPtr item = m_canvas->getFirstItemAt(e->pos());
 
     // If we're in segmentAddMode or not clicking on an item then we don't
     // clear the selection vector.  If we're clicking on an item and it's
@@ -237,20 +237,20 @@ SegmentSelector::handleMouseButtonRelease(QMouseEvent *e)
 
     if (m_canvas->getModel()->isSelected(m_currentIndex)) {
 
-        CompositionModelImpl::itemcontainer& changingItems = m_canvas->getModel()->getChangingItems();
-        CompositionModelImpl::itemcontainer::iterator it;
+        CompositionModelImpl::ItemContainer& changingItems = m_canvas->getModel()->getChangingItems();
+        CompositionModelImpl::ItemContainer::iterator it;
 
         if (changeMade()) {
 
             SegmentReconfigureCommand *command =
                 new SegmentReconfigureCommand
-                (tr("Move Segment(s)", "", m_selectedItems.size()));
+                (tr("Move Segment(s)", "", m_selectedItems.size()), &comp);
 
             for (it = changingItems.begin();
                     it != changingItems.end();
                     ++it) {
 
-                CompositionItem item = *it;
+                CompositionItemPtr item = *it;
 
                 Segment* segment = CompositionItemHelper::getSegment(item);
 
@@ -302,7 +302,7 @@ SegmentSelector::handleMouseButtonRelease(QMouseEvent *e)
 
     m_selectionMoveStarted = false;
 
-    m_currentIndex = CompositionItem();
+    m_currentIndex = CompositionItemPtr();
 
     setContextHelpFor(e->pos());
 }
@@ -410,10 +410,10 @@ SegmentSelector::handleMouseMove(QMouseEvent *e)
             m_selectionMoveStarted = true;
         }
 
-        CompositionModelImpl::itemcontainer& changingItems = m_canvas->getModel()->getChangingItems();
+        CompositionModelImpl::ItemContainer& changingItems = m_canvas->getModel()->getChangingItems();
         setCurrentIndex(CompositionItemHelper::findSiblingCompositionItem(changingItems, m_currentIndex));
 
-        CompositionModelImpl::itemcontainer::iterator it;
+        CompositionModelImpl::ItemContainer::iterator it;
         int guideX = 0;
         int guideY = 0;
 
@@ -503,7 +503,7 @@ void SegmentSelector::setContextHelpFor(QPoint p, bool ctrlPressed)
     }
     settings.endGroup();
 
-    CompositionItem item = m_canvas->getFirstItemAt(p);
+    CompositionItemPtr item = m_canvas->getFirstItemAt(p);
 
     if (!item) {
         setContextHelp(tr("Click and drag to select segments; middle-click and drag to draw an empty segment"));
