@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -62,7 +62,7 @@ SegmentSplitter::handleMouseButtonPress(QMouseEvent *e)
 {
     // Remove cursor and replace with line on a SegmentItem
     // at where the cut will be made
-    CompositionItem item = m_canvas->getFirstItemAt(e->pos());
+    CompositionItemPtr item = m_canvas->getFirstItemAt(e->pos());
 
     if (item) {
         m_canvas->viewport()->setCursor(Qt::BlankCursor);
@@ -79,7 +79,7 @@ SegmentSplitter::handleMouseButtonRelease(QMouseEvent *e)
 {
     setBasicContextHelp();
 
-    CompositionItem item = m_canvas->getFirstItemAt(e->pos());
+    CompositionItemPtr item = m_canvas->getFirstItemAt(e->pos());
 
     if (item) {
         m_canvas->setSnapGrain(true);
@@ -113,7 +113,7 @@ SegmentSplitter::handleMouseMove(QMouseEvent *e)
 {
     setBasicContextHelp();
 
-    CompositionItem item = m_canvas->getFirstItemAt(e->pos());
+    CompositionItemPtr item = m_canvas->getFirstItemAt(e->pos());
 
     if (item) {
 //        m_canvas->viewport()->setCursor(Qt::blankCursor);
