@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This file originally from Sonic Visualiser, copyright 2007 Queen
     Mary, University of London.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_AUTO_SAVE_FINDER_H_
-#define _RG_AUTO_SAVE_FINDER_H_
+#ifndef RG_AUTO_SAVE_FINDER_H
+#define RG_AUTO_SAVE_FINDER_H
 
 #include <QString>
 
