@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -298,7 +298,8 @@ EditViewBase::slotSetSegmentStartTime()
     if (dialog.exec() == QDialog::Accepted) {
 
         SegmentReconfigureCommand *command =
-            new SegmentReconfigureCommand(tr("Set Segment Start Time"));
+            new SegmentReconfigureCommand(tr("Set Segment Start Time"),
+                    &getDocument()->getComposition());
 
         command->addSegment
         (s, dialog.getTime(),
@@ -325,7 +326,8 @@ EditViewBase::slotSetSegmentDuration()
     if (dialog.exec() == QDialog::Accepted) {
 
         SegmentReconfigureCommand *command =
-            new SegmentReconfigureCommand(tr("Set Segment Duration"));
+            new SegmentReconfigureCommand(tr("Set Segment Duration"),
+                    &getDocument()->getComposition());
 
         command->addSegment
         (s, s->getStartTime(),
