@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,8 +16,8 @@
 */
 
 
-#ifndef _RG_EDITVIEWTIMESIGNOTIFIER_H_
-#define _RG_EDITVIEWTIMESIGNOTIFIER_H_
+#ifndef RG_EDITVIEWTIMESIGNOTIFIER_H
+#define RG_EDITVIEWTIMESIGNOTIFIER_H
 
 namespace Rosegarden {
         
