@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This file originally from Sonic Visualiser, copyright 2007 Queen
     Mary, University of London.
@@ -564,6 +564,8 @@ FileSource::ftpCommandFinished(int id, bool error)
 {
 #ifdef DEBUG_FILE_SOURCE
     std::cerr << "FileSource::ftpCommandFinished(" << id << ", " << error << ")" << std::endl;
+#else
+    (void)id;
 #endif
 
     if (!m_ftp) return;
