@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -12,8 +12,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_RESOURCE_FINDER_H_
-#define _RG_RESOURCE_FINDER_H_
+#ifndef RG_RESOURCE_FINDER_H
+#define RG_RESOURCE_FINDER_H
 
 #include <QString>
 
