@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _SELECTION_MANAGER_H_
-#define _SELECTION_MANAGER_H_
+#ifndef RG_SELECTION_MANAGER_H
+#define RG_SELECTION_MANAGER_H
 
 namespace Rosegarden
 {
