@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _CONTROLITEM_H
-#define _CONTROLITEM_H
+#ifndef RG_CONTROLITEM_H
+#define RG_CONTROLITEM_H
 
 #include <QPolygonF>
 #include <QColor>
@@ -41,7 +41,7 @@ public:
                 Event* event,
                 QPolygonF polygon);
 
-    ~ControlItem();
+    virtual ~ControlItem();
 
     virtual void setValue(float);
     float y() const { return m_y; }
