@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -61,18 +61,18 @@ class InternalSegmentMapper : public SegmentMapper
     friend class ControllerSearch;
     friend class ControllerContextMap;
 
-    class Callback : public ChannelManager::MapperFunctionality
+    class Callbacks : public ChannelManager::Callbacks
         {
         public:
     
-        Callback(InternalSegmentMapper *mapper) :
+        Callbacks(InternalSegmentMapper *mapper) :
             m_mapper(mapper) {}
         private:
             virtual ControllerAndPBList
                 getControllers(Instrument *instrument, RealTime start);
             InternalSegmentMapper *m_mapper;
         };
-    friend class Callback;
+    friend class Callbacks;
 
     typedef std::pair<timeT, int> Noteoff;
     struct NoteoffCmp
@@ -94,6 +94,9 @@ class InternalSegmentMapper : public SegmentMapper
     ~InternalSegmentMapper(void);
 
     // Do channel-setup
+    virtual void makeReady(MappedInserterBase &inserter, RealTime time);
+
+    // Insert the event "evt"
     virtual void doInsert(MappedInserterBase &inserter, MappedEvent &evt,
                          RealTime start, bool firstOutput);
 
