@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -162,6 +162,11 @@ doInsert(MappedInserterBase &inserter, MappedEvent &evt,
     inserter.insertCopy(evt);
 }
 
+// The default doesn't have to do anything to get ready.
+void
+MappedEventBuffer::
+makeReady(MappedInserterBase &/*inserter*/, RealTime /*time*/) {}
+
 void
 MappedEventBuffer::
 addOwner(void)
@@ -341,7 +346,7 @@ doInsert(MappedInserterBase &inserter, MappedEvent &evt)
         m_currentTime = evt.getEventTime();
 
     // Mapper does the actual insertion.
-    getSegment()->doInsert(inserter, evt, m_currentTime, !getReady());
+    getSegment()->doInsert(inserter, evt, m_currentTime, !isReady());
     setReady(true);
 }
 
