@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -256,11 +256,21 @@ void
 MetronomeMapper::doInsert(MappedInserterBase &inserter, MappedEvent &evt,
                          RealTime start, bool firstOutput)
 {
-    ChannelManager::MapperFunctionalitySimple callback;
-    m_channelManager.doInsert(inserter, evt, start, &callback,
+    ChannelManager::SimpleCallbacks callbacks;
+    m_channelManager.doInsert(inserter, evt, start, &callbacks,
                               firstOutput, NO_TRACK);
 }
 
+void
+MetronomeMapper::
+makeReady(MappedInserterBase &inserter, RealTime time)
+{
+    ChannelManager::SimpleCallbacks callbacks;
+    // m_channelManager.setInstrument(m_doc->getStudio().getInstrumentById(getMetronomeInstrument()));
+    m_channelManager.makeReady(inserter, time, &callbacks,
+                               NO_TRACK);
+}
+
 bool
 MetronomeMapper::
 mutedEtc(MappedEvent *evt)
