@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -69,6 +69,12 @@ FileDialog::FileDialog(QWidget *parent,
          ; // closing ; on this line to allow the lines above to be shuffled easily
 
     setSidebarUrls(urls);
+
+    // NOTE: This code only executes if the Thorn style is in use, so there is
+    // no need for conditional execution here.  Go straight to it, and hack the
+    // stylesheet.  This fixes #1396, by ensuring that the file dialog has white
+    // in the right places, even at deep levels of style inheritance.
+    setStyleSheet("QAbstractScrollArea { background: #FFFFFF;} QLineEdit { background: #FFFFFF; }");
 }
 
 
