@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     This file is based on KLed from the KDE libraries
     Copyright (C) 1998 Jrg Habenicht (j.habenicht@europemail.com)
@@ -18,8 +18,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _LED_H_
-#define _LED_H_
+#ifndef RG_LED_H
+#define RG_LED_H
 
 #include <QWidget>
 
