@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_ROSEGARDENROTARY_H_
-#define _RG_ROSEGARDENROTARY_H_
+#ifndef RG_ROTARY_H
+#define RG_ROTARY_H
 
 #include <map>
 #include <QColor>
@@ -125,8 +125,8 @@ protected:
 
     struct CacheIndex {
 
-        CacheIndex(int _s, int _c, int _a, int _n, int _ct) :
-            size(_s), colour(_c), angle(_a), numTicks(_n), centred(_ct) { }
+        CacheIndex(int s, int c, int a, int n, int ct) :
+            size(s), colour(c), angle(a), numTicks(n), centred(ct) { }
 
         bool operator<(const CacheIndex &i) const {
             // woo!
