@@ -2,7 +2,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -12,8 +12,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _ROSEGARDEN_SQUEEZED_LABEL_H_
-#define _ROSEGARDEN_SQUEEZED_LABEL_H_
+#ifndef RG_SQUEEZED_LABEL_H
+#define RG_SQUEEZED_LABEL_H
 
 #include <QLabel>
 
@@ -112,8 +112,8 @@ protected:
     */
     void squeezeTextToLabel();
 
-    private:
-    Q_PRIVATE_SLOT(d, void _k_copyFullText())
+private:
+    Q_PRIVATE_SLOT(d, void k_copyFullText())
     SqueezedLabelPrivate * const d;
 };
 
