@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -55,4 +55,6 @@ namespace Rosegarden
     const char* const RecentDirsConfigGroup = "RecentDirs";
     const char* const CollapsingFrameConfigGroup = "CollapsingFrame";
     const char* const PitchBendSequenceConfigGroup = "PitchBendSequence";
+    const char* const CheckButtonConfigGroup = "CheckButton_Memory";
+    const char* const SelectDialogConfigGroup = "SelectDialog_Memory";
 }
