@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@ namespace Rosegarden {
     class RealTime;
     class Colour;
     namespace Guitar {
-	class Chord;
+        class Chord;
     }
 
 #if !defined NDEBUG && !defined RG_NO_DEBUG_PRINT
@@ -71,6 +71,9 @@ public:
 
 #endif
 
+#define DEFINE_DUMMY_PRINTER(TYPE)                              \
+QDebug &operator<<(QDebug &dbg, const TYPE &) { return dbg; }
+
 }
 
 #endif
