@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -12,8 +12,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _AUDIOFILE_H_
-#define _AUDIOFILE_H_
+#ifndef RG_AUDIOFILE_H
+#define RG_AUDIOFILE_H
 
 #include <string>
 #include <vector>
@@ -212,4 +212,4 @@ protected:
 }
 
 
-#endif /// _AUDIOFILE_H_
+#endif /// RG_AUDIOFILE_H
