@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -30,8 +30,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _AUDIO_TIME_STRETCHER_H_
-#define _AUDIO_TIME_STRETCHER_H_
+#ifndef RG_AUDIO_TIME_STRETCHER_H
+#define RG_AUDIO_TIME_STRETCHER_H
 
 #include "SampleWindow.h"
 #include "RingBuffer.h"
