@@ -2,7 +2,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -12,8 +12,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _EXTERNAL_TRANSPORT_H_
-#define _EXTERNAL_TRANSPORT_H_
+#ifndef RG_EXTERNAL_TRANSPORT_H
+#define RG_EXTERNAL_TRANSPORT_H
 
 namespace Rosegarden {
 
