@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
  
     This program is free software; you can redistribute it and/or
@@ -23,7 +23,9 @@
 #include "PluginFactory.h"
 
 #include "misc/ConfigGroups.h"
+
 #include <QSettings>
+#include <QtGlobal>
 
 #ifdef HAVE_ALSA
 #ifdef HAVE_LIBJACK
@@ -65,7 +67,7 @@ JackDriver::JackDriver(AlsaDriver *alsaDriver) :
         m_framesProcessed(0),
         m_ok(false)
 {
-    assert(sizeof(sample_t) == sizeof(float));
+    Q_ASSERT(sizeof(sample_t) == sizeof(float));
     initialise();
 }
 
@@ -213,12 +215,25 @@ JackDriver::initialise(bool reinitialise)
 
     std::string jackClientName = "rosegarden";
 
+    // set up JackOpenOptions per user config
+    QSettings settings;
+    settings.beginGroup(SequencerOptionsConfigGroup);
+    bool autoStartJack = settings.value("autostartjack", true).toBool();
+    settings.endGroup();
+    // default is to auto start JACK; use JackNullOption
+    jack_options_t jackOptions = JackNullOption;
+    if (!autoStartJack) jackOptions = JackNoStartServer;
+
     // attempt connection to JACK server
     //
-    if ((m_client = jack_client_open(jackClientName.c_str(), JackNullOption, 0)) == 0) {
+    if ((m_client = jack_client_open(jackClientName.c_str(), jackOptions, 0)) == 0) {
         audit << "JackDriver::initialiseAudio - "
 	      << "JACK server not running"
-	      << std::endl;
+	      << std::endl
+              << "Attempt to start JACK server was "
+              << (jackOptions & JackNoStartServer ? "NOT " : "")
+              << "made per user config"
+              << std::endl;
         return ;
     }
 
@@ -310,10 +325,10 @@ JackDriver::initialise(bool reinitialise)
     }
 
     // Now set up the default connections, if configured to do so
-    QSettings settings;
     settings.beginGroup(SequencerOptionsConfigGroup);
     bool connectDefaultOutputs = settings.value("connect_default_jack_outputs", true).toBool();
     bool connectDefaultInputs = settings.value("connect_default_jack_inputs", true).toBool();
+    settings.endGroup();
 
     const char **ports = jack_get_ports(m_client, NULL, NULL,
             JackPortIsPhysical | JackPortIsInput);
