@@ -3,7 +3,7 @@
 /*
   Rosegarden
   A sequencer and musical notation editor.
-  Copyright 2000-2013 the Rosegarden development team.
+  Copyright 2000-2014 the Rosegarden development team.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -12,12 +12,14 @@
   COPYING included with this distribution for more information.
 */
 
-#include <iostream>
-#include <cassert>
 
 #include "LADSPAPluginInstance.h"
 #include "LADSPAPluginFactory.h"
 
+#include <QtGlobal>
+
+#include <iostream>
+
 //#define DEBUG_LADSPA 1
 
 namespace Rosegarden
@@ -298,8 +300,8 @@ LADSPAPluginInstance::connectPorts()
     if (!m_descriptor || !m_descriptor->connect_port)
         return ;
 
-    assert(sizeof(LADSPA_Data) == sizeof(float));
-    assert(sizeof(sample_t) == sizeof(float));
+    Q_ASSERT(sizeof(LADSPA_Data) == sizeof(float));
+    Q_ASSERT(sizeof(sample_t) == sizeof(float));
 
     size_t inbuf = 0, outbuf = 0;
 
