@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -23,7 +23,9 @@
 #include "misc/Debug.h"
 #include "sound/MidiFile.h"
 #include "sound/MappedEvent.h"
-#include "assert.h"
+
+#include <QtGlobal>
+
 #include <string>
 
 // #define MIDI_DEBUG 1
@@ -216,7 +218,7 @@ void
 MidiInserter::
 insertCopy(const MappedEvent &evt)
 {
-    assert(!m_finished);
+    Q_ASSERT(!m_finished);
 
     MidiByte   midiChannel = evt.getRecordedChannel();
     TrackData& trackData   = getTrackData(evt.getTrackId(), midiChannel);
