@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
  
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -20,8 +20,8 @@
 #include "SoundFile.h"
 #include "base/RealTime.h"
 
-#ifndef _PEAKFILE_H_
-#define _PEAKFILE_H_
+#ifndef RG_PEAKFILE_H
+#define RG_PEAKFILE_H
 
 // A PeakFile is generated to the BWF Supplement 3 Peak Envelope Chunk
 // format as defined here:
@@ -185,6 +185,6 @@ protected:
 }
 
 
-#endif // _PEAKFILE_H_
+#endif // RG_PEAKFILE_H
 
 
