@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2013 the Rosegarden development team.
+    Copyright 2000-2014 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -21,8 +21,8 @@
 //
 //
 
-#ifndef _PEAKFILEMANAGER_H_
-#define _PEAKFILEMANAGER_H_
+#ifndef RG_PEAKFILEMANAGER_H
+#define RG_PEAKFILEMANAGER_H
 
 #include <string>
 #include <iostream>
@@ -152,6 +152,6 @@ protected:
 }
 
 
-#endif // _PEAKFILEMANAGER_H_
+#endif // RG_PEAKFILEMANAGER_H
 
 
